# Generated by Django 2.2.15 on 2020-08-18 15:12

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('galaxy', '0004_update_synclist_policy_names'),
        ('galaxy', '0003_inbound_repo_per_namespace'),
    ]

    operations = [
    ]
