# Generated by Django 2.2.19 on 2021-03-18 00:37

from django.db import migrations, models
import django.db.models.deletion
import django_lifecycle.mixins
import galaxy_ng.app.access_control.mixins


class Migration(migrations.Migration):

    dependencies = [
        ('core', '0061_call_handle_artifact_checksums_command'),
        ('container', '0018_containerdistribution_description'),
        ('galaxy', '0015_containerdistroreadme'),
    ]

    operations = [
        migrations.CreateModel(
            name='ContainerRegistryRemote',
            fields=[
                ('remote_ptr', models.OneToOneField(auto_created=True, on_delete=django.db.models.deletion.CASCADE, parent_link=True, primary_key=True, related_name='galaxy_containerregistryremote', serialize=False, to='core.Remote')),
            ],
            options={
                'default_related_name': '%(app_label)s_%(model_name)s',
            },
            bases=('core.remote', galaxy_ng.app.access_control.mixins.GroupModelPermissionsMixin),
        ),
        migrations.CreateModel(
            name='ContainerSyncTask',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('repository', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='container.ContainerRepository')),
                ('task', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='core.Task')),
            ],
            options={
                'ordering': ['-task__finished_at'],
            },
        ),
        migrations.CreateModel(
            name='ContainerRegistryRepos',
            fields=[
                ('repository_remote', models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, primary_key=True, serialize=False, to='container.ContainerRemote')),
                ('registry', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='galaxy.ContainerRegistryRemote')),
            ],
        ),
    ]
