"use strict";(self.webpackChunkansible_hub_ui=self.webpackChunkansible_hub_ui||[]).push([[252],{83913:(e,s,a)=>{a.d(s,{Z:()=>u});var n=a(87462),t=a(4942),c=a(45987),r=a(67294),i=a(45697),l=a.n(i),o=a(94184),m=a.n(o);const d=r.createContext("light");var p=function(e){var s=e.className,a=e.children,i=(0,c.Z)(e,["className","children"]),l=m()(s,"pf-l-page-header","pf-c-page-header","pf-l-page__main-section","pf-c-page__main-section");return r.createElement(d.Consumer,null,(function(){var e=arguments.length>0&&void 0!==arguments[0]?arguments[0]:"light",s=m()((0,t.Z)({},"pf-m-".concat(e,"-200"),"dark"===e),(0,t.Z)({},"pf-m-light","light"===e));return r.createElement("section",(0,n.Z)({},i,{className:"".concat(l," ").concat(s),"widget-type":"InsightsPageHeader"}),a)}))};const u=p;p.propTypes={children:l().any.isRequired,className:l().string}},39173:(e,s,a)=>{a.d(s,{Z:()=>m});var n=a(67294),t=a(45697),c=a.n(t),r=a(94184),i=a.n(r),l=a(60485),o=function(e){var s=e.className,a=e.title,t=i()(s);return n.createElement(l.D,{headingLevel:"h1",size:"2xl",className:t,"widget-type":"InsightsPageHeaderTitle"}," ",a," ")};const m=o;o.propTypes={title:c().node.isRequired,className:c().string}},54213:(e,s,a)=>{a.d(s,{Z:()=>p});var n=a(87462),t=a(4942),c=a(45987),r=a(67294),i=a(45697),l=a.n(i),o=a(94184),m=a.n(o),d=function(e){var s=e.type,a=e.children,i=e.className,l=(0,c.Z)(e,["type","children","className"]),o=m()(i,(0,t.Z)({},"ins-l-".concat(s),void 0!==s));return r.createElement("section",(0,n.Z)({},l,{className:o})," ",a," ")};const p=d;d.propTypes={type:l().string,className:l().string,children:l().any.isRequired}},56455:(e,s,a)=>{a.d(s,{Z:()=>u});var n=a(87462),t=a(4942),c=a(45987),r=a(67294),i=a(45697),l=a.n(i),o=a(94184),m=a.n(o),d={xs:"xs",sm:"sm",md:"md",lg:"lg"},p=function(e){var s=e.size,a=e.isDark,i=e.className,l=(0,c.Z)(e,["size","isDark","className"]),o=m()("ins-c-skeleton","ins-c-skeleton__".concat(s),(0,t.Z)({},"ins-m-dark",a),i);return r.createElement("div",(0,n.Z)({className:o},l)," ")};const u=p;p.propTypes={className:l().string,size:l().oneOf(Object.values(d)),isDark:l().bool},p.defaultProps={size:d.md,isDark:!1}},6023:(e,s,a)=>{a.d(s,{Z:()=>p});var n=a(87462),t=a(4942),c=a(45987),r=a(67294),i=a(45697),l=a.n(i),o=a(94184),m=a.n(o),d=function(e){var s=e.centered,a=e.className,i=(0,c.Z)(e,["centered","className"]),l=m()("ins-c-spinner",(0,t.Z)({},"ins-m-center",s),a);return r.createElement("div",(0,n.Z)({role:"status",className:l},i),r.createElement("span",{className:"pf-u-screen-reader"},"Loading..."))};d.propTypes={centered:l().bool,className:l().string};const p=d}}]);
//# sourceMappingURL=../sourcemaps/rhcsVendor.027e89dfc20dfaa6abeb.js.map