# Generated by Django 2.2.20 on 2021-04-10 17:49

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('galaxy', '0019_containernamespace'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='collectionsynctask',
            options={'ordering': ['-task__pulp_last_updated']},
        ),
    ]
