:root{--ins-color--orange: #ec7a08}.body{background-color:#fff;padding:16px}.clickable{cursor:pointer}#page-sidebar>div{padding-top:0px}#page-sidebar{border-top-style:solid;border-top-width:var(--pf-global--BorderWidth--sm);border-top-color:var(--pf-global--palette--black-800)}section.pf-c-nav__section.nav-title>h2{height:50px;font-size:var(--pf-c-nav__link--FontSize);font-weight:var(--pf-c-nav__link--FontWeight)}pre{background-color:#f8f8f8;border:1px solid #e6e9e9;font-family:var(--pf-global--FontFamily--monospace);display:block;padding:10px}pre code{font-family:var(--pf-global--FontFamily--monospace)}body,#root{height:100%}
.certification-dasboard .toolbar{padding-bottom:16px;display:flex;justify-content:space-between}.certification-dasboard .control-column{display:flex;justify-content:flex-end;align-items:center}.certification-dasboard .footer{padding-top:16px}.certification-dasboard .updating-spinner{color:var(--pf-global--info-color--100)}
.tag{margin:4px}
.card-row{display:flex}@media(max-width: 1000px){.card-row{flex-direction:column-reverse}}.card-row .fields{flex-grow:1;margin-right:15px}@media(min-width: 1000px){.card-row .card{border-left:24px solid #ededed;border-bottom:24px solid #ededed;margin-top:-15px;margin-right:-15px}}.useful-links{display:flex;margin-bottom:10px}.useful-links .link-name{flex-grow:1}.useful-links .link-url{flex-grow:2;margin-left:20px}.useful-links .link-button{display:flex;align-items:center;margin-left:10px}.useful-links .link-button .link-container{width:20px}.account-ids{display:flex;margin-bottom:10px}.account-ids .account-id{flex-grow:1}.account-ids .account-add{flex-grow:2;margin-left:20px;margin-top:5px}.account-ids .account-button{display:flex;align-items:center;margin-left:10px}
.image{padding-right:16px}.title-box{display:flex;align-items:center}.column-section{display:flex;justify-content:space-between}.column-section .header-right{align-items:right}.background{background-color:#fff;padding:0px 24px 0px 24px}.placeholder{height:24px}.breadcrumb-container{padding-top:10px;padding-bottom:10px}.header-bottom{padding-top:10px}.tab-link-container{display:flex;margin-top:10px}@media(max-width: 1000px){.tab-link-container{flex-direction:column-reverse}}.tab-link-container .tabs{flex-grow:0}.tab-link-container .pf-c-tabs__item.disabled .pf-c-tabs__link{cursor:not-allowed}.tab-link-container .links{flex-grow:1;display:flex;align-items:center;flex-wrap:wrap}@media(min-width: 1000px){.tab-link-container .links{justify-content:flex-end}}@media(max-width: 1000px){.tab-link-container .links{margin-bottom:10px}}@media(min-width: 1000px){.tab-link-container .links div{margin-left:20px}}@media(max-width: 1000px){.tab-link-container .links div{margin-right:20px}}
.controls{display:flex;justify-content:space-between;padding-left:24px;padding-right:24px}.top{padding-top:0px;padding-bottom:16px}.bottom{padding-top:16px;padding-bottom:0px}
.entry{margin-top:5px}.right-col{width:200px}.content{text-transform:capitalize}
.ns-card-container{width:300px}.ns-card-container .title{font-weight:bold}.ns-card-container .ns-name{text-overflow:ellipsis;overflow:hidden;white-space:nowrap;width:180px}.collection-card-container{width:280px}.collection-card-container div{display:block}.collection-card-container .name{font-weight:bold;text-overflow:ellipsis;overflow:hidden;white-space:nowrap;width:100%}.collection-card-container .type-label{font-size:var(--pf-global--FontSize--xs);color:var(--pf-global--color--200);text-transform:capitalize}.collection-card-container .type-container{display:flex;justify-content:space-between}.collection-card-container .logo-row{display:flex;justify-content:space-between}.collection-card-container .logo-row .icon{color:var(--pf-global--info-color--100);margin-right:3px}.collection-card-container .description{height:48px;overflow:hidden}
.sort-wrapper{display:flex;align-items:center}.asc-button{margin-left:5px}
.selected-item{background-color:#edf8ff}.status-icon{font-size:12px}.sub-text{font-weight:normal}.namespace-selector{width:100%}.loading{height:500px;display:flex;align-items:center;justify-content:center}.namespace-selector-wrapper{display:flex;align-items:center;margin-bottom:16px}.namespace-selector-wrapper .label{width:100px;color:#000;text-align:left}.namespace-selector-wrapper .selector{flex-grow:1}.import-list .list-container{display:flex;align-items:center;padding:10px;border-bottom:1px solid #ededed}.import-list .list-container .left{margin-right:10px}.import-list .list-container:hover{background-color:#edf8ff}.import-list .search-box{margin-bottom:24px}.import-console .title-bar{position:relative;margin-top:15px;margin-bottom:20px;background-color:#f0f0f0;min-height:25px;padding:10px;border:1px solid #e1e1e1;border-radius:2px}.import-console .title-bar .data-title{font-weight:bold}.import-console .title-bar .stats{text-align:right;font-size:12px;color:#363636}.import-console .title-container{display:inline-block}.import-console .title-container .title{display:inline;font-size:18px}.import-console .title-container .refreshing-icon{display:inline;font-size:18px;margin-left:10px;opacity:0;transition:2s ease}.import-console .title-container .refreshing-icon.refreshing{opacity:1}.import-console .last-message{height:100px;width:5px;position:relative;top:-150px}.import-console .message-list{background-color:#363636;padding:10px;border:1px solid #363636;border-radius:2px;color:#fff;line-height:18px;margin-bottom:50px}.import-console .message-list .log-follow-button{position:relative;top:0;float:right;font-size:18px}.import-console .message-list .follow-active{color:#5bb75b}.error,.failed{color:#ff5850}.warning{color:#f90}.success{color:#5bb75b}
.icon{margin-left:8px;color:var(--pf-global--icon--Color--light)}.icon:hover{color:var(--pf-global--link--Color--dark)}.selected{color:var(--pf-global--link--Color--dark)}
.install-title{min-width:100px;vertical-align:middle;display:table-cell}.readme-container{position:relative;max-height:300px;min-height:50px;overflow:hidden}.fade-out{position:absolute;z-index:1;bottom:0;left:0;pointer-events:none;background-image:linear-gradient(to bottom, rgba(255, 255, 255, 0), white 90%);width:100%;height:50px}.download-button{padding-left:0px}.info-panel{padding:8px}
.content-table{width:100%}.content-table th{font-weight:bold}.type-selector{margin-left:16px;text-transform:capitalize}.selected-item,.type-selector:hover{border-bottom:2px solid var(--pf-global--link--Color);padding-bottom:2px;margin-bottom:-4px;background-color:#fff}
.active{color:#00659c}.inactive{color:#9c9c9c}
.helper{padding:0px}
.markdown-editor{display:flex}@media(max-width: 1000px){.markdown-editor{flex-direction:column-reverse}}.markdown-editor .column{flex-grow:1;margin-right:15px;margin-bottom:15px}.markdown-editor .preview-container .preview{overflow:scroll;height:500px;border:1px solid #ededed;padding:5px}.markdown-editor .editor{min-width:500px;max-width:500px}#resources{height:500px;resize:none}
.input-group-text-no-wrap{white-space:nowrap}
.main{margin:0px;padding:0px}.header{border-bottom:1px solid #d8d8d8}.docs-container{padding-top:24px;background-color:#fff}@media(min-width: 1000px){.docs-container{display:flex}}.docs-container .sidebar{min-width:294px;max-width:294px;border-right:1px solid #d8d8d8;padding:0px;padding-top:0px}.docs-container .docs{flex-grow:1;padding:24px;padding-top:0px;overflow-x:auto;min-height:calc(100vh - 250px)}.docs-container .docs table tr:nth-child(2n){background-color:#f2f2f2}.docs-container .docs table td,.docs-container .docs table th{border:1px solid #ccc;padding:5px}.docs-container pre{white-space:pre-wrap}
.page-container{display:flex}.page-container .import-list{width:400px}.page-container .import-console{flex-grow:1;margin-left:10px}
.upload-collection .file-error-messages{color:#c00}.upload-collection .upload-file{width:.1px;height:.1px;opacity:0;overflow:hidden;position:absolute;z-index:-1}.upload-collection .upload-file-label{display:inline-block;cursor:pointer;width:100%;font-weight:normal}.upload-collection .upload-file-label .upload-box{display:flex;border-style:solid;border-width:thin;width:100%;border-radius:3px}.upload-collection .upload-file-label .upload-box .upload-button,.upload-collection .upload-file-label .upload-box .upload-text{padding:5px}.upload-collection .upload-file-label .upload-box .upload-button{border-right:thin solid;padding-left:10px;padding-right:10px}.upload-collection .upload-file-label .upload-box .upload-button:hover{color:#fff;background-color:gray}.upload-collection .upload-file-label .upload-box .upload-text{position:relative;width:100%}.upload-collection .upload-file-label .upload-box .loading-bar{position:absolute;height:3px;background-color:#5bb75b;bottom:0px;left:0px}
.namespace-page{height:100%;display:flex;flex-direction:column;justify-content:space-between}.namespace-page .card-area{margin-top:24px;margin-left:24px;flex-grow:1}.namespace-page .card-area .card-layout{display:flex;flex-wrap:wrap}.namespace-page .card-area .card-layout .card-wrapper{margin-right:24px;margin-bottom:24px}.namespace-page .toolbar{display:flex;justify-content:space-between}.namespace-page .footer{border-top:1px solid #d8d8d8;flex-shrink:0}
.bullseye-center{display:flex;align-items:center;flex-direction:column}.bullseye{min-height:calc(100vh - 230px)}.four-oh-four{font-size:30pt}
.search-page{height:100%;display:flex;flex-direction:column}.search-page .toolbar-wrapper .toolbar{display:flex;justify-content:space-between;align-items:center}.search-page .toolbar-wrapper .toolbar .pagination-container{display:flex;align-items:center}.search-page .toolbar-wrapper .toolbar .pagination-container .card-list-switcher{margin-right:24px}.search-page .header{border-bottom:1px solid #d8d8d8}.search-page .collection-container{padding-top:24px;flex-grow:1}.search-page .collection-container .cards{display:flex;flex-wrap:wrap;align-content:flex-start}.search-page .collection-container .cards .card{margin-left:24px;margin-bottom:24px}.search-page .collection-container .list-container{width:100%}.search-page .collection-container .list{margin-bottom:24px;margin-left:24px;margin-right:24px;padding-top:16px;padding-bottom:16px;overflow:hidden}.search-page .collection-container .list .data-list{margin-top:-17px;margin-bottom:-17px}.search-page .collection-container .empty{flex-grow:1}.search-page .footer{border-top:1px solid #d8d8d8;flex-shrink:0}
.truncated{max-height:3rem;text-overflow:ellipsis;overflow:hidden}.edit-button{float:right}
.tags-column{max-width:250px}
.single-line-ellipsis{overflow:hidden;text-overflow:ellipsis;white-space:nowrap}.layers-max-width{max-width:45%;word-wrap:break-word}.eco-clipboard-copy{display:inline-block}.eco-clipboard-copy .pf-c-clipboard-copy__group{align-items:baseline}.eco-clipboard-copy input{width:37em;border:none;background:transparent !important;text-overflow:ellipsis;padding:var(--custom-override);margin:var(--custom-override)}.eco-clipboard-copy button{padding:0;margin-left:5px !important;color:var(--pf-global--Color--200) !important}.eco-clipboard-copy .pf-c-button::after{border:none !important;padding:var(--custom-override);margin:var(--custom-override)}

/*# sourceMappingURL=App.555d62dd7549a336dd0a.css.map*/