:root {
  --ins-color--orange: #ec7a08;
}

i.Ansible.is-supported .st0 {
  fill: var(--pf-global--info-color--100);
}
i.Ansible.is-unsupported {
  cursor: not-allowed;
}
i.Ansible.is-unsupported .st0, i.Ansible.is-unsupported .st1, i.Ansible.is-unsupported .st2 {
  fill: var(--pf-global--disabled-color--200);
}
i.Ansible svg {
  height: var(--pf-global--FontSize--xl);
  position: relative;
  top: 4px;
  top: 0.25rem;
}

:root {
  --ins-color--orange: #ec7a08;
}

i.ins-battery {
  display: inline-block;
  line-height: 0;
}
i.ins-battery svg {
  position: relative;
  top: var(--pf-global--spacer--sm);
  position: relative;
  height: 28px;
  height: 1.75rem;
}

.ins-battery-1 svg path, .ins-battery-low svg path, .ins-battery-info svg path {
  fill: var(--pf-global--disabled-color--200);
}

.ins-battery-2 svg path, .ins-battery-medium svg path, .ins-battery-warn svg path {
  fill: var(--pf-global--warning-color--100);
}

.ins-battery-3 svg path, .ins-battery-high svg path, .ins-battery-error svg path {
  fill: var(--ins-color--orange);
}

.ins-battery-4 svg path, .ins-battery-critical svg path {
  fill: var(--pf-global--danger-color--100);
}

.ins-battery-0 svg path, .ins-battery-null svg path {
  fill: var(--pf-global--disabled-color--200);
}

.ins-c-bulk-select .pf-c-dropdown__toggle-check span.pf-c-dropdown__toggle-text {
  display: initial;
}
.ins-c-bulk-select .ins-c-bulk-select__selected {
  display: none;
}

@media only screen and (max-width: 768px) {
  .ins-c-bulk-select .pf-c-dropdown__toggle-check span.pf-c-dropdown__toggle-text {
    display: none;
  }
  .ins-c-bulk-select .ins-c-bulk-select__selected {
    display: initial;
  }
}
:root {
  --ins-color--orange: #ec7a08;
}

.ins-c-conditional-filter.mobile {
  display: none !important;
  visibility: hidden !important;
}
.ins-c-conditional-filter .pf-c-select__toggle-wrapper .pf-c-select__toggle-text {
  max-width: 150px;
  max-width: 9.375rem;
}
.ins-c-conditional-filter .ins-c-conditional-filter__group .pf-c-dropdown__toggle-text {
  width: 102px;
  text-align: left;
}
.ins-c-conditional-filter .ins-c-conditional-filter__group .pf-c-dropdown__toggle-text > svg {
  margin-right: var(--pf-global--spacer--xs);
}
.ins-c-conditional-filter .ins-c-conditional-filter__group .ins-c-conditional-filter__no-label .pf-c-dropdown__toggle-text {
  width: auto;
}
.ins-c-conditional-filter .pf-l-split__item .pf-c-select__menu-group {
  padding: 0;
}
.ins-c-conditional-filter .pf-l-split__item .pf-c-select__menu-group .pf-c-select__menu-group-title:empty {
  display: none;
}
.ins-c-conditional-filter .pf-l-split__item .pf-c-select__option-button {
  padding: 0;
}
.ins-c-conditional-filter .pf-l-split__item .pf-c-select__menu-item-icon {
  display: none;
}
.ins-c-conditional-filter input.ins-c-conditional-filter[type=text] {
  padding-right: 35px;
  padding-right: 2.1875rem;
  margin-right: -23px;
  margin-right: -1.4375rem;
}
.ins-c-conditional-filter input.ins-c-conditional-filter[type=text] + svg {
  position: relative;
  left: -5px;
  left: -0.3125rem;
  top: 2px;
  top: 0.125rem;
}
.ins-c-conditional-filter .pf-c-select__toggle-text {
  margin-right: 0;
}
.ins-c-conditional-filter .pf-c-select__toggle-badge {
  display: none;
}
.ins-c-conditional-filter .pf-c-menu-toggle {
  padding: 0;
}
.ins-c-conditional-filter .pf-c-menu-toggle .pf-c-menu-toggle__text {
  flex: 1;
}
.ins-c-conditional-filter .pf-c-menu-toggle .pf-c-menu-toggle__text input {
  border: none;
}

.pf-c-menu .ins-c-menu__show--more:hover {
  background: none;
}
.pf-c-menu .ins-c-menu__show--more .pf-c-menu__item-text {
  color: var(--pf-global--active-color--100);
}

@media only screen and (max-width: 768px) {
  .ins-c-conditional-filter.mobile {
    visibility: visible !important;
    display: grid !important;
  }
  .ins-c-conditional-filter.desktop {
    visibility: hidden;
    display: none;
  }
}
@media only screen and (max-width: 884px) {
  .ins-c-conditional-filter .ins-c-conditional-filter__group .pf-c-dropdown__toggle-text {
    width: auto;
  }
  .ins-c-conditional-filter .ins-c-conditional-filter__group .ins-c-conditional-filter__value-selector {
    display: none;
  }
  .ins-c-conditional-filter .ins-c-conditional-filter__group .ins-c-conditional-filter__group {
    width: initial;
  }
}
.ins-c-inventory__culling-warning {
  color: var(--pf-global--warning-color--100);
}

.ins-c-inventory__culling-danger {
  color: var(--pf-global--danger-color--100);
}

.ins-c-inventory__culling-danger, .ins-c-inventory__culling-warning {
  font-weight: var(--pf-global--FontWeight--bold);
}
.ins-c-inventory__culling-danger svg, .ins-c-inventory__culling-warning svg {
  margin-right: var(--pf-global--spacer--sm);
}

:root {
  --ins-color--orange: #ec7a08;
}

.ins-c-table__empty {
  background: var(--pf-global--Color--light-100);
  border-bottom: 1px solid var(--pf-global--BorderColor--light-200);
  padding: 20px;
  padding: 1.25rem;
}
.ins-c-table__empty.is-centered {
  display: flex;
  justify-content: center;
}

.ins-c-chip-filters .ins-c-chip-group__plain.pf-m-toolbar > li:not(.pf-m-overflow) {
  background: none;
  padding: 0;
  background-color: initial;
}
.ins-c-chip-filters .ins-c-chip-group__plain.pf-m-toolbar > li:not(.pf-m-overflow) h4 {
  display: none;
}

.ins-c-chip-filters .pf-c-chip-group:not(:last-child) {
  margin-right: var(--pf-global--spacer--sm);
}

.ins-c-tagfilter .ins-c-tagfilter__option label {
  display: flex;
  width: 100%;
}
.ins-c-tagfilter .ins-c-tagfilter__option label .ins-c-tagfilter__option-value {
  max-width: 12.5rem;
  overflow: hidden;
  text-overflow: ellipsis;
}
.ins-c-tagfilter .ins-c-tagfilter__option label .pf-c-badge {
  margin-left: auto;
  padding-top: 0.2;
}
.ins-c-tagfilter .pf-c-select__menu-group-title:empty {
  display: none;
}
.ins-c-tagfilter .pf-c-select__menu > div {
  padding-top: 0;
}
.ins-c-tagfilter.pf-m-expanded {
  width: 18.75rem !important;
}

.ins-c-filter__dropdown .pf-c-dropdown__menu-item:hover {
  background-color: inherit !important;
  outline: inherit !important;
}
.ins-c-filter__dropdown .pf-c-dropdown__menu-item:focus {
  background-color: inherit !important;
  outline: inherit !important;
}

.ins-c-critical-icon {
  width: 10px;
  height: 10px;
  stroke: var(--pf-global--palette--red-200);
  stroke-width: 0.5px;
  fill: var(--pf-global--palette--red-200);
  margin: 0.25px;
}

.pf-c-label {
  --ins-c-label--red-bg: #faeae8;
  --inc-c-label--content-red: var(--pf-global--palette--red-300);
  --inc-c-label--icon-red: var(--pf-global--palette--red-200);
  --ins-c-label--orange-bg: #FFF5EC;
  --inc-c-label--content-orange: #773D00;
  --inc-c-label--icon-orange: var(--pf-global--palette--orange-300);
  --ins-c-label--gold-bg: #fdf7e7;
  --inc-c-label--content-gold: var(--pf-global--palette--gold-700);
  --inc-c-label--icon-gold: #F4C145;
  --ins-c-label--blue-bg: var(--pf-global--palette--blue-50);
  --inc-c-label--content-blue: var(--pf-global--palette--blue-600);
  --inc-c-label--icon-blue: var(--pf-global--palette--blue-300);
}

.ins-c-label-4.pf-c-label {
  background-color: var(--ins-c-label--red-bg);
}
.ins-c-label-4.pf-c-label .pf-c-label__content {
  color: var(--inc-c-label--content-red);
}
.ins-c-label-4.pf-c-label .pf-c-label__content .pf-c-label__icon {
  color: var(--inc-c-label--icon-red);
}

.ins-c-label-3.pf-c-label {
  background-color: var(--ins-c-label--orange-bg);
}
.ins-c-label-3.pf-c-label .pf-c-label__content {
  color: var(--inc-c-label--content-orange);
}
.ins-c-label-3.pf-c-label .pf-c-label__content .pf-c-label__icon {
  color: var(--inc-c-label--icon-orange);
}

.ins-c-label-2.pf-c-label {
  background-color: var(--ins-c-label--gold-bg);
}
.ins-c-label-2.pf-c-label .pf-c-label__content {
  color: var(--inc-c-label--content-gold);
}
.ins-c-label-2.pf-c-label .pf-c-label__content .pf-c-label__icon {
  color: var(--inc-c-label--icon-gold);
}

.ins-c-label-1.pf-c-label {
  background-color: var(--ins-c-label--blue-bg);
}
.ins-c-label-1.pf-c-label .pf-c-label__content {
  color: var(--inc-c-label--content-blue);
}
.ins-c-label-1.pf-c-label .pf-c-label__content .pf-c-label__icon {
  color: var(--inc-c-label--icon-blue);
}

.Icon404 {
  height: 150px;
}
.Icon404 .cls-1 {
  fill: #fff;
}
.Icon404 .cls-1, .Icon404 .cls-3 {
  fill-rule: evenodd;
}
.Icon404 .cls-2 {
  opacity: 0.5;
}
.Icon404 .cls-4 {
  mask: url(#mask);
}

:root {
  --ins-color--orange: #ec7a08;
}

.ins-c-component_invalid-componet {
  display: flex;
  justify-content: center;
  flex-direction: column;
  align-items: center;
  text-align: center;
}
.ins-c-component_invalid-componet .ins-c-text__sorry {
  max-width: 70%;
}
.ins-c-component_invalid-componet h1, .ins-c-component_invalid-componet svg {
  margin-bottom: 30px;
  margin-bottom: 1.875rem;
}
.ins-c-component_invalid-componet button {
  font-size: 20px;
  font-size: 1.25rem;
}

.pf-l-page__main .pf-l-page__main-section.pf-m-dark:not(:first-child) {
  background: var(--pf-global--BackgroundColor--dark-transparent-100);
}

.ins-c-empty-state__maintenance .pf-c-empty-state__body {
  color: var(--pf-global--Color--100);
}
.ins-c-empty-state__maintenance .pf-c-empty-state__icon {
  fill: #EE0000;
}
.ins-c-empty-state__maintenance .pf-c-title {
  font-weight: 500;
}

.ins-c-not-authorized .pf-c-title {
  max-width: 540px;
  margin-left: auto;
  margin-right: auto;
}

:root {
  --ins-color--orange: #ec7a08;
}

.pf-l-page__main-section.pf-l-page-header.pf-m-dark-200 h1.pf-c-title.pf-m-2xl, .pf-l-page__main-section.pf-l-page-header.pf-m-dark-200 * {
  color: #fff;
}

.pf-l-page__main-section.pf-l-page-header .pf-c-breadcrumb {
  display: block;
  margin-bottom: 15px;
  margin-bottom: 0.9375rem;
}

.pf-c-form-control, .pf-c-input-group {
  --pf-global--Color--100: var(--pf-global--Color--dark-100);
  --pf-global--Color--200: var(--pf-global--Color--dark-200);
  --pf-global--BorderColor--100: var(--pf-global--BorderColor--dark-100);
  --pf-global--primary-color--100: var(--pf-global--primary-color--dark-100);
  --pf-global--link--Color: var(--pf-global--link--Color--dark);
  --pf-global--link--Color--hover: var(--pf-global--link--Color--dark--hover);
  --pf-global--BackgroundColor--100: var(--pf-global--BackgroundColor--light-100);
}

.pf-c-pagination {
  --pf-c-pagination--child--MarginRight: var(--pf-global--spacer--lg);
  --pf-c-pagination--m-bottom--child--MarginRight: 0;
  --pf-c-pagination--m-bottom--child--md--MarginRight: var(--pf-global--spacer--lg);
  --pf-c-pagination--m-compact--child--MarginRight: var(--pf-global--spacer--sm);
  --pf-c-pagination--c-options-menu__toggle--FontSize: var(--pf-global--FontSize--sm);
  --pf-c-pagination__nav--Display: none;
  --pf-c-pagination__nav--Visibility: hidden;
  --pf-c-pagination--m-display-summary__nav--Display: none;
  --pf-c-pagination--m-display-summary__nav--Visibility: hidden;
  --pf-c-pagination--m-display-full__nav--Display: inline-flex;
  --pf-c-pagination--m-display-full__nav--Visibility: visible;
  --pf-c-pagination__nav-control--c-button--PaddingRight: var(--pf-global--spacer--sm);
  --pf-c-pagination__nav-control--c-button--PaddingLeft: var(--pf-global--spacer--sm);
  --pf-c-pagination__nav-control--c-button--FontSize: var(--pf-global--FontSize--md);
  --pf-c-pagination--m-bottom__nav-control--c-button--OutlineOffset: calc(var(--pf-global--spacer--xs) * -1);
  --pf-c-pagination--m-bottom__nav-control--c-button--PaddingTop: var(--pf-global--spacer--md);
  --pf-c-pagination--m-bottom__nav-control--c-button--PaddingBottom: var(--pf-global--spacer--md);
  --pf-c-pagination--m-bottom__nav-control--c-button--PaddingRight: var(--pf-global--spacer--md);
  --pf-c-pagination--m-bottom__nav-control--c-button--PaddingRight: var(--pf-global--spacer--md);
  --pf-c-pagination--m-bottom__nav-control--c-button--md--PaddingTop: var(--pf-global--spacer--form-element);
  --pf-c-pagination--m-bottom__nav-control--c-button--md--PaddingRight: var(--pf-global--spacer--sm);
  --pf-c-pagination--m-bottom__nav-control--c-button--md--PaddingBottom: var(--pf-global--spacer--form-element);
  --pf-c-pagination--m-bottom__nav-control--c-button--md--PaddingLeft: var(--pf-global--spacer--sm);
  --pf-c-pagination--m-compact__nav-control--nav-control--MarginLeft: var(--pf-global--spacer--md);
  --pf-c-pagination__nav-page-select--FontSize: var(--pf-global--FontSize--sm);
  --pf-c-pagination__nav-page-select--PaddingLeft: var(--pf-global--spacer--md);
  --pf-c-pagination__nav-page-select--PaddingRight: var(--pf-global--spacer--md);
  --pf-c-pagination__nav-page-select--child--MarginRight: var(--pf-global--spacer--xs);
  --pf-c-pagination__nav-page-select--c-form-control--width-base: 3.5ch;
  --pf-c-pagination__nav-page-select--c-form-control--width-chars: 2;
  --pf-c-pagination__nav-page-select--c-form-control--Width: calc(var(--pf-c-pagination__nav-page-select--c-form-control--width-base) + (var(--pf-c-pagination__nav-page-select--c-form-control--width-chars) * 1ch));
  --pf-c-pagination__total-items--Display: block;
  --pf-c-pagination__total-items--Visibility: visible;
  --pf-c-pagination--m-display-summary__total-items--Display: block;
  --pf-c-pagination--m-display-summary__total-items--Visibility: visible;
  --pf-c-pagination--m-display-full__total-items--Display: none;
  --pf-c-pagination--m-display-full__total-items--Visibility: hidden;
  --pf-c-pagination--m-sticky--BackgroundColor: var(--pf-global--BackgroundColor--100);
  --pf-c-pagination--m-sticky--BoxShadow: var(--pf-global--BoxShadow--sm-bottom);
  --pf-c-pagination--m-sticky--md--PaddingTop: var(--pf-global--spacer--md);
  --pf-c-pagination--m-sticky--md--PaddingRight: var(--pf-global--spacer--md);
  --pf-c-pagination--m-sticky--md--PaddingBottom: var(--pf-global--spacer--md);
  --pf-c-pagination--m-sticky--md--PaddingLeft: var(--pf-global--spacer--md);
  --pf-c-pagination--m-sticky--ZIndex: var(--pf-global--ZIndex--xs);
  --pf-c-pagination--m-sticky--Top: 0;
  --pf-c-pagination--m-bottom--BackgroundColor: var(--pf-global--BackgroundColor--100);
  --pf-c-pagination--m-bottom--BoxShadow: var(--pf-global--BoxShadow--sm-top);
  --pf-c-pagination--m-bottom--Bottom: 0;
  --pf-c-pagination--m-bottom--md--PaddingTop: var(--pf-global--spacer--md);
  --pf-c-pagination--m-bottom--md--PaddingRight: var(--pf-global--spacer--md);
  --pf-c-pagination--m-bottom--md--PaddingBottom: var(--pf-global--spacer--md);
  --pf-c-pagination--m-bottom--md--PaddingLeft: var(--pf-global--spacer--md);
  --pf-c-pagination--m-bottom--xl--PaddingRight: var(--pf-global--spacer--lg);
  --pf-c-pagination--m-bottom--xl--PaddingLeft: var(--pf-global--spacer--lg);
  --pf-c-pagination--m-bottom--m-sticky--BoxShadow: var(--pf-global--BoxShadow--sm-top);
  --pf-c-pagination--c-options-menu--Display: none;
  --pf-c-pagination--c-options-menu--Visibility: hidden;
  --pf-c-pagination--m-display-summary--c-options-menu--Display: none;
  --pf-c-pagination--m-display-summary--c-options-menu--Visibility: hidden;
  --pf-c-pagination--m-display-full--c-options-menu--Display: inline-flex;
  --pf-c-pagination--m-display-full--c-options-menu--Visibility: visible;
  display: flex;
  flex-wrap: wrap;
  align-items: center;
  justify-content: flex-end;
}
@media screen and (min-width: 768px) {
  .pf-c-pagination {
    --pf-c-pagination--m-bottom__nav-control--c-button--PaddingTop: var(--pf-c-pagination--m-bottom__nav-control--c-button--md--PaddingTop);
    --pf-c-pagination--m-bottom__nav-control--c-button--PaddingRight: var(--pf-c-pagination--m-bottom__nav-control--c-button--md--PaddingRight);
    --pf-c-pagination--m-bottom__nav-control--c-button--PaddingBottom: var(--pf-c-pagination--m-bottom__nav-control--c-button--md--PaddingBottom);
    --pf-c-pagination--m-bottom__nav-control--c-button--PaddingLeft: var(--pf-c-pagination--m-bottom__nav-control--c-button--md--PaddingLeft);
    --pf-c-pagination--m-bottom--child--MarginRight: var(--pf-c-pagination--m-bottom--child--md--MarginRight);
    --pf-c-pagination--m-bottom__nav-control--c-button--OutlineOffset: 0;
    --pf-c-pagination--m-bottom--BoxShadow: none;
    --pf-c-pagination--c-options-menu--Display: inline-flex;
    --pf-c-pagination--c-options-menu--Visibility: visible;
    --pf-c-pagination__nav--Display: inline-flex;
    --pf-c-pagination__nav--Visibility: visible;
    --pf-c-pagination__total-items--Display: none;
    --pf-c-pagination__total-items--Visibility: hidden;
  }
}
@media screen and (min-width: 1200px) {
  .pf-c-pagination {
    --pf-c-pagination--m-bottom--md--PaddingRight: var(--pf-c-pagination--m-bottom--xl--PaddingRight);
    --pf-c-pagination--m-bottom--md--PaddingLeft: var(--pf-c-pagination--m-bottom--xl--PaddingLeft);
  }
}
.pf-c-pagination > *:not(:last-child):not(.pf-c-pagination__total-items) {
  margin-right: var(--pf-c-pagination--child--MarginRight);
}
.pf-c-pagination .pf-c-options-menu {
  display: var(--pf-c-pagination--c-options-menu--Display);
  visibility: var(--pf-c-pagination--c-options-menu--Visibility);
}
.pf-c-pagination.pf-m-bottom {
  --pf-c-pagination--child--MarginRight: var(--pf-c-pagination--m-bottom--child--MarginRight);
  --pf-c-pagination__nav-control--c-button--PaddingRight: var(--pf-c-pagination--m-bottom__nav-control--c-button--PaddingRight);
  --pf-c-pagination__nav-control--c-button--PaddingLeft: var(--pf-c-pagination--m-bottom__nav-control--c-button--PaddingRight);
  --pf-c-pagination--m-sticky--BoxShadow: var(--pf-c-pagination--m-bottom--m-sticky--BoxShadow);
  --pf-c-pagination--m-sticky--Top: auto;
  position: sticky;
  bottom: var(--pf-c-pagination--m-bottom--Bottom);
  justify-content: center;
  background-color: var(--pf-c-pagination--m-bottom--BackgroundColor);
  box-shadow: var(--pf-c-pagination--m-bottom--BoxShadow);
}
.pf-c-pagination.pf-m-bottom .pf-c-pagination__nav-control .pf-c-button {
  --pf-c-button--PaddingTop: var(--pf-c-pagination--m-bottom__nav-control--c-button--PaddingTop);
  --pf-c-button--PaddingBottom: var(--pf-c-pagination--m-bottom__nav-control--c-button--PaddingBottom);
  outline-offset: var(--pf-c-pagination--m-bottom__nav-control--c-button--OutlineOffset);
}
.pf-c-pagination.pf-m-bottom.pf-m-static {
  --pf-c-pagination--m-bottom--MarginTop: 0;
  --pf-c-pagination--m-bottom--BorderTopWidth: 0;
  position: relative;
  box-shadow: none;
}
.pf-c-pagination.pf-m-bottom .pf-c-pagination__nav-control.pf-m-first,
.pf-c-pagination.pf-m-bottom .pf-c-pagination__nav-control.pf-m-last,
.pf-c-pagination.pf-m-bottom .pf-c-pagination__nav-page-select {
  display: none;
  visibility: hidden;
}
.pf-c-pagination.pf-m-bottom .pf-c-options-menu {
  position: absolute;
  display: block;
  visibility: visible;
}
.pf-c-pagination.pf-m-bottom .pf-c-pagination__nav {
  display: flex;
  flex-basis: 100%;
  justify-content: space-between;
  visibility: visible;
}
@media screen and (min-width: 768px) {
  .pf-c-pagination.pf-m-bottom {
    --pf-c-pagination--m-bottom--BorderTopWidth: 0;
    --pf-c-pagination--m-bottom--MarginTop: 0;
    --pf-c-pagination--m-bottom--Bottom: auto;
    position: relative;
    justify-content: flex-end;
    padding: var(--pf-c-pagination--m-bottom--md--PaddingTop) var(--pf-c-pagination--m-bottom--md--PaddingRight) var(--pf-c-pagination--m-bottom--md--PaddingBottom) var(--pf-c-pagination--m-bottom--md--PaddingLeft);
  }
  .pf-c-pagination.pf-m-bottom .pf-c-pagination__nav-control.pf-m-first,
.pf-c-pagination.pf-m-bottom .pf-c-pagination__nav-control.pf-m-last,
.pf-c-pagination.pf-m-bottom .pf-c-pagination__nav-page-select {
    display: block;
    visibility: visible;
  }
  .pf-c-pagination.pf-m-bottom .pf-c-options-menu {
    position: relative;
  }
  .pf-c-pagination.pf-m-bottom .pf-c-pagination__nav {
    display: inline-flex;
    flex-basis: auto;
  }
}
.pf-c-pagination.pf-m-sticky {
  --pf-c-pagination--m-bottom--Bottom: 0;
  position: sticky;
  top: var(--pf-c-pagination--m-sticky--Top);
  z-index: var(--pf-c-pagination--m-sticky--ZIndex);
  padding-top: var(--pf-c-pagination--m-sticky--PaddingTop);
  padding-right: var(--pf-c-pagination--m-sticky--PaddingRight);
  padding-bottom: var(--pf-c-pagination--m-sticky--PaddingBottom);
  padding-left: var(--pf-c-pagination--m-sticky--PaddingLeft);
  background-color: var(--pf-c-pagination--m-sticky--BackgroundColor);
  box-shadow: var(--pf-c-pagination--m-sticky--BoxShadow);
}
@media screen and (min-width: 768px) {
  .pf-c-pagination.pf-m-sticky {
    padding: var(--pf-c-pagination--m-sticky--md--PaddingTop) var(--pf-c-pagination--m-sticky--md--PaddingRight) var(--pf-c-pagination--m-sticky--md--PaddingBottom) var(--pf-c-pagination--m-sticky--md--PaddingLeft);
  }
}
.pf-c-pagination .pf-c-options-menu__toggle {
  font-size: var(--pf-c-pagination--c-options-menu__toggle--FontSize);
}
.pf-c-pagination.pf-m-compact {
  --pf-c-pagination--child--MarginRight: var(--pf-c-pagination--m-compact--child--MarginRight);
}

.pf-c-pagination__nav {
  display: var(--pf-c-pagination__nav--Display);
  justify-content: flex-end;
  visibility: var(--pf-c-pagination__nav--Visibility);
}

.pf-c-pagination__nav-control .pf-c-button {
  padding-right: var(--pf-c-pagination__nav-control--c-button--PaddingRight);
  padding-left: var(--pf-c-pagination__nav-control--c-button--PaddingLeft);
  font-size: var(--pf-c-pagination__nav-control--c-button--FontSize);
}
.pf-c-pagination.pf-m-compact .pf-c-pagination__nav-control + .pf-c-pagination__nav-control {
  margin-left: var(--pf-c-pagination--m-compact__nav-control--nav-control--MarginLeft);
}

.pf-c-pagination__nav-page-select {
  display: flex;
  align-items: center;
  padding-right: var(--pf-c-pagination__nav-page-select--PaddingRight);
  padding-left: var(--pf-c-pagination__nav-page-select--PaddingLeft);
}
.pf-c-pagination__nav-page-select > * {
  font-size: var(--pf-c-pagination__nav-page-select--FontSize);
  white-space: nowrap;
}
.pf-c-pagination__nav-page-select > *:not(:last-child) {
  margin-right: var(--pf-c-pagination__nav-page-select--child--MarginRight);
}
.pf-c-pagination__nav-page-select .pf-c-form-control {
  width: var(--pf-c-pagination__nav-page-select--c-form-control--Width);
}

.pf-c-pagination__total-items {
  display: var(--pf-c-pagination__total-items--Display);
  visibility: var(--pf-c-pagination__total-items--Visibility);
}

.pf-c-pagination.pf-m-display-summary {
  --pf-c-pagination__nav--Display: var(--pf-c-pagination--m-display-summary__nav--Display);
  --pf-c-pagination__nav--Visibility: var(--pf-c-pagination--m-display-summary__nav--Visibility);
  --pf-c-pagination--c-options-menu--Display: var(--pf-c-pagination--m-display-summary--c-options-menu--Display);
  --pf-c-pagination--c-options-menu--Visibility: var(--pf-c-pagination--m-display-summary--c-options-menu--Visibility);
  --pf-c-pagination__total-items--Display: var(--pf-c-pagination--m-display-summary__total-items--Display);
  --pf-c-pagination__total-items--Visibility: var(--pf-c-pagination--m-display-summary__total-items--Visibility);
}
.pf-c-pagination.pf-m-display-full {
  --pf-c-pagination__nav--Display: var(--pf-c-pagination--m-display-full__nav--Display);
  --pf-c-pagination__nav--Visibility: var(--pf-c-pagination--m-display-full__nav--Visibility);
  --pf-c-pagination--c-options-menu--Display: var(--pf-c-pagination--m-display-full--c-options-menu--Display);
  --pf-c-pagination--c-options-menu--Visibility: var(--pf-c-pagination--m-display-full--c-options-menu--Visibility);
  --pf-c-pagination__total-items--Display: var(--pf-c-pagination--m-display-full__total-items--Display);
  --pf-c-pagination__total-items--Visibility: var(--pf-c-pagination--m-display-full__total-items--Visibility);
}
@media (min-width: 576px) {
  .pf-c-pagination.pf-m-display-summary-on-sm {
    --pf-c-pagination__nav--Display: var(--pf-c-pagination--m-display-summary__nav--Display);
    --pf-c-pagination__nav--Visibility: var(--pf-c-pagination--m-display-summary__nav--Visibility);
    --pf-c-pagination--c-options-menu--Display: var(--pf-c-pagination--m-display-summary--c-options-menu--Display);
    --pf-c-pagination--c-options-menu--Visibility: var(--pf-c-pagination--m-display-summary--c-options-menu--Visibility);
    --pf-c-pagination__total-items--Display: var(--pf-c-pagination--m-display-summary__total-items--Display);
    --pf-c-pagination__total-items--Visibility: var(--pf-c-pagination--m-display-summary__total-items--Visibility);
  }
  .pf-c-pagination.pf-m-display-full-on-sm {
    --pf-c-pagination__nav--Display: var(--pf-c-pagination--m-display-full__nav--Display);
    --pf-c-pagination__nav--Visibility: var(--pf-c-pagination--m-display-full__nav--Visibility);
    --pf-c-pagination--c-options-menu--Display: var(--pf-c-pagination--m-display-full--c-options-menu--Display);
    --pf-c-pagination--c-options-menu--Visibility: var(--pf-c-pagination--m-display-full--c-options-menu--Visibility);
    --pf-c-pagination__total-items--Display: var(--pf-c-pagination--m-display-full__total-items--Display);
    --pf-c-pagination__total-items--Visibility: var(--pf-c-pagination--m-display-full__total-items--Visibility);
  }
}
@media (min-width: 768px) {
  .pf-c-pagination.pf-m-display-summary-on-md {
    --pf-c-pagination__nav--Display: var(--pf-c-pagination--m-display-summary__nav--Display);
    --pf-c-pagination__nav--Visibility: var(--pf-c-pagination--m-display-summary__nav--Visibility);
    --pf-c-pagination--c-options-menu--Display: var(--pf-c-pagination--m-display-summary--c-options-menu--Display);
    --pf-c-pagination--c-options-menu--Visibility: var(--pf-c-pagination--m-display-summary--c-options-menu--Visibility);
    --pf-c-pagination__total-items--Display: var(--pf-c-pagination--m-display-summary__total-items--Display);
    --pf-c-pagination__total-items--Visibility: var(--pf-c-pagination--m-display-summary__total-items--Visibility);
  }
  .pf-c-pagination.pf-m-display-full-on-md {
    --pf-c-pagination__nav--Display: var(--pf-c-pagination--m-display-full__nav--Display);
    --pf-c-pagination__nav--Visibility: var(--pf-c-pagination--m-display-full__nav--Visibility);
    --pf-c-pagination--c-options-menu--Display: var(--pf-c-pagination--m-display-full--c-options-menu--Display);
    --pf-c-pagination--c-options-menu--Visibility: var(--pf-c-pagination--m-display-full--c-options-menu--Visibility);
    --pf-c-pagination__total-items--Display: var(--pf-c-pagination--m-display-full__total-items--Display);
    --pf-c-pagination__total-items--Visibility: var(--pf-c-pagination--m-display-full__total-items--Visibility);
  }
}
@media (min-width: 992px) {
  .pf-c-pagination.pf-m-display-summary-on-lg {
    --pf-c-pagination__nav--Display: var(--pf-c-pagination--m-display-summary__nav--Display);
    --pf-c-pagination__nav--Visibility: var(--pf-c-pagination--m-display-summary__nav--Visibility);
    --pf-c-pagination--c-options-menu--Display: var(--pf-c-pagination--m-display-summary--c-options-menu--Display);
    --pf-c-pagination--c-options-menu--Visibility: var(--pf-c-pagination--m-display-summary--c-options-menu--Visibility);
    --pf-c-pagination__total-items--Display: var(--pf-c-pagination--m-display-summary__total-items--Display);
    --pf-c-pagination__total-items--Visibility: var(--pf-c-pagination--m-display-summary__total-items--Visibility);
  }
  .pf-c-pagination.pf-m-display-full-on-lg {
    --pf-c-pagination__nav--Display: var(--pf-c-pagination--m-display-full__nav--Display);
    --pf-c-pagination__nav--Visibility: var(--pf-c-pagination--m-display-full__nav--Visibility);
    --pf-c-pagination--c-options-menu--Display: var(--pf-c-pagination--m-display-full--c-options-menu--Display);
    --pf-c-pagination--c-options-menu--Visibility: var(--pf-c-pagination--m-display-full--c-options-menu--Visibility);
    --pf-c-pagination__total-items--Display: var(--pf-c-pagination--m-display-full__total-items--Display);
    --pf-c-pagination__total-items--Visibility: var(--pf-c-pagination--m-display-full__total-items--Visibility);
  }
}
@media (min-width: 1200px) {
  .pf-c-pagination.pf-m-display-summary-on-xl {
    --pf-c-pagination__nav--Display: var(--pf-c-pagination--m-display-summary__nav--Display);
    --pf-c-pagination__nav--Visibility: var(--pf-c-pagination--m-display-summary__nav--Visibility);
    --pf-c-pagination--c-options-menu--Display: var(--pf-c-pagination--m-display-summary--c-options-menu--Display);
    --pf-c-pagination--c-options-menu--Visibility: var(--pf-c-pagination--m-display-summary--c-options-menu--Visibility);
    --pf-c-pagination__total-items--Display: var(--pf-c-pagination--m-display-summary__total-items--Display);
    --pf-c-pagination__total-items--Visibility: var(--pf-c-pagination--m-display-summary__total-items--Visibility);
  }
  .pf-c-pagination.pf-m-display-full-on-xl {
    --pf-c-pagination__nav--Display: var(--pf-c-pagination--m-display-full__nav--Display);
    --pf-c-pagination__nav--Visibility: var(--pf-c-pagination--m-display-full__nav--Visibility);
    --pf-c-pagination--c-options-menu--Display: var(--pf-c-pagination--m-display-full--c-options-menu--Display);
    --pf-c-pagination--c-options-menu--Visibility: var(--pf-c-pagination--m-display-full--c-options-menu--Visibility);
    --pf-c-pagination__total-items--Display: var(--pf-c-pagination--m-display-full__total-items--Display);
    --pf-c-pagination__total-items--Visibility: var(--pf-c-pagination--m-display-full__total-items--Visibility);
  }
}
@media (min-width: 1450px) {
  .pf-c-pagination.pf-m-display-summary-on-2xl {
    --pf-c-pagination__nav--Display: var(--pf-c-pagination--m-display-summary__nav--Display);
    --pf-c-pagination__nav--Visibility: var(--pf-c-pagination--m-display-summary__nav--Visibility);
    --pf-c-pagination--c-options-menu--Display: var(--pf-c-pagination--m-display-summary--c-options-menu--Display);
    --pf-c-pagination--c-options-menu--Visibility: var(--pf-c-pagination--m-display-summary--c-options-menu--Visibility);
    --pf-c-pagination__total-items--Display: var(--pf-c-pagination--m-display-summary__total-items--Display);
    --pf-c-pagination__total-items--Visibility: var(--pf-c-pagination--m-display-summary__total-items--Visibility);
  }
  .pf-c-pagination.pf-m-display-full-on-2xl {
    --pf-c-pagination__nav--Display: var(--pf-c-pagination--m-display-full__nav--Display);
    --pf-c-pagination__nav--Visibility: var(--pf-c-pagination--m-display-full__nav--Visibility);
    --pf-c-pagination--c-options-menu--Display: var(--pf-c-pagination--m-display-full--c-options-menu--Display);
    --pf-c-pagination--c-options-menu--Visibility: var(--pf-c-pagination--m-display-full--c-options-menu--Visibility);
    --pf-c-pagination__total-items--Display: var(--pf-c-pagination--m-display-full__total-items--Display);
    --pf-c-pagination__total-items--Visibility: var(--pf-c-pagination--m-display-full__total-items--Visibility);
  }
}

.pf-c-options-menu {
  --pf-c-options-menu__toggle--BackgroundColor: transparent;
  --pf-c-options-menu__toggle--PaddingTop: var(--pf-global--spacer--form-element);
  --pf-c-options-menu__toggle--PaddingRight: var(--pf-global--spacer--sm);
  --pf-c-options-menu__toggle--PaddingBottom: var(--pf-global--spacer--form-element);
  --pf-c-options-menu__toggle--PaddingLeft: var(--pf-global--spacer--sm);
  --pf-c-options-menu__toggle--MinWidth: 0;
  --pf-c-options-menu__toggle--LineHeight: var(--pf-global--LineHeight--md);
  --pf-c-options-menu__toggle--BorderWidth: var(--pf-global--BorderWidth--sm);
  --pf-c-options-menu__toggle--BorderTopColor: var(--pf-global--BorderColor--300);
  --pf-c-options-menu__toggle--BorderRightColor: var(--pf-global--BorderColor--300);
  --pf-c-options-menu__toggle--BorderBottomColor: var(--pf-global--BorderColor--200);
  --pf-c-options-menu__toggle--BorderLeftColor: var(--pf-global--BorderColor--300);
  --pf-c-options-menu__toggle--Color: var(--pf-global--Color--100);
  --pf-c-options-menu__toggle--hover--BorderBottomColor: var(--pf-global--active-color--100);
  --pf-c-options-menu__toggle--active--BorderBottomWidth: var(--pf-global--BorderWidth--md);
  --pf-c-options-menu__toggle--active--BorderBottomColor: var(--pf-global--active-color--100);
  --pf-c-options-menu__toggle--focus--BorderBottomWidth: var(--pf-global--BorderWidth--md);
  --pf-c-options-menu__toggle--focus--BorderBottomColor: var(--pf-global--active-color--100);
  --pf-c-options-menu__toggle--expanded--BorderBottomWidth: var(--pf-global--BorderWidth--md);
  --pf-c-options-menu__toggle--expanded--BorderBottomColor: var(--pf-global--active-color--100);
  --pf-c-options-menu__toggle--disabled--BackgroundColor: var(--pf-global--disabled-color--300);
  --pf-c-options-menu__toggle--m-plain--Color: var(--pf-global--Color--200);
  --pf-c-options-menu__toggle--m-plain--hover--Color: var(--pf-global--Color--100);
  --pf-c-options-menu__toggle--m-plain--disabled--Color: var(--pf-global--disabled-color--200);
  --pf-c-options-menu__toggle--m-plain--PaddingRight: var(--pf-global--spacer--md);
  --pf-c-options-menu__toggle--m-plain--PaddingLeft: var(--pf-global--spacer--md);
  --pf-c-options-menu__toggle-icon--MarginRight: var(--pf-global--spacer--sm);
  --pf-c-options-menu__toggle-icon--MarginLeft: var(--pf-global--spacer--md);
  --pf-c-options-menu--m-top--m-expanded__toggle-icon--Rotate: 180deg;
  --pf-c-options-menu__toggle-button--BackgroundColor: transparent;
  --pf-c-options-menu__toggle-button--PaddingTop: var(--pf-global--spacer--form-element);
  --pf-c-options-menu__toggle-button--PaddingRight: var(--pf-global--spacer--sm);
  --pf-c-options-menu__toggle-button--PaddingBottom: var(--pf-global--spacer--form-element);
  --pf-c-options-menu__toggle-button--PaddingLeft: var(--pf-global--spacer--sm);
  --pf-c-options-menu__menu--BackgroundColor: var(--pf-global--BackgroundColor--light-100);
  --pf-c-options-menu__menu--BoxShadow: var(--pf-global--BoxShadow--md);
  --pf-c-options-menu__menu--PaddingTop: var(--pf-global--spacer--sm);
  --pf-c-options-menu__menu--PaddingBottom: var(--pf-global--spacer--sm);
  --pf-c-options-menu__menu--Top: calc(100% + var(--pf-global--spacer--xs));
  --pf-c-options-menu__menu--ZIndex: var(--pf-global--ZIndex--sm);
  --pf-c-options-menu--m-top__menu--Top: 0;
  --pf-c-options-menu--m-top__menu--TranslateY: calc(-100% - var(--pf-global--spacer--xs));
  --pf-c-options-menu__menu-item--BackgroundColor: transparent;
  --pf-c-options-menu__menu-item--Color: var(--pf-global--Color--100);
  --pf-c-options-menu__menu-item--FontSize: var(--pf-global--FontSize--md);
  --pf-c-options-menu__menu-item--PaddingTop: var(--pf-global--spacer--sm);
  --pf-c-options-menu__menu-item--PaddingRight: var(--pf-global--spacer--md);
  --pf-c-options-menu__menu-item--PaddingBottom: var(--pf-global--spacer--sm);
  --pf-c-options-menu__menu-item--PaddingLeft: var(--pf-global--spacer--md);
  --pf-c-options-menu__menu-item--disabled--Color: var(--pf-global--Color--dark-200);
  --pf-c-options-menu__menu-item--hover--BackgroundColor: var(--pf-global--BackgroundColor--light-300);
  --pf-c-options-menu__menu-item--disabled--BackgroundColor: transparent;
  --pf-c-options-menu__menu-item-icon--Color: var(--pf-global--active-color--100);
  --pf-c-options-menu__menu-item-icon--FontSize: var(--pf-global--icon--FontSize--sm);
  --pf-c-options-menu__menu-item-icon--PaddingLeft: var(--pf-global--spacer--lg);
  --pf-c-options-menu__group--group--PaddingTop: var(--pf-global--spacer--sm);
  --pf-c-options-menu__group-title--PaddingTop: var(--pf-global--spacer--sm);
  --pf-c-options-menu__group-title--PaddingRight: var(--pf-c-options-menu__menu-item--PaddingRight);
  --pf-c-options-menu__group-title--PaddingBottom: var(--pf-c-options-menu__menu-item--PaddingBottom);
  --pf-c-options-menu__group-title--PaddingLeft: var(--pf-c-options-menu__menu-item--PaddingLeft);
  --pf-c-options-menu__group-title--FontSize: var(--pf-global--FontSize--sm);
  --pf-c-options-menu__group-title--FontWeight: var(--pf-global--FontWeight--semi-bold);
  --pf-c-options-menu__group-title--Color: var(--pf-global--Color--dark-200);
  --pf-c-options-menu--c-divider--MarginTop: var(--pf-global--spacer--sm);
  --pf-c-options-menu--c-divider--MarginBottom: var(--pf-global--spacer--sm);
  position: relative;
  display: inline-block;
  max-width: 100%;
}
.pf-c-options-menu .pf-c-divider {
  margin-top: var(--pf-c-options-menu--c-divider--MarginTop);
  margin-bottom: var(--pf-c-options-menu--c-divider--MarginBottom);
}
.pf-c-options-menu .pf-c-divider:last-child {
  --pf-c-options-menu--c-divider--MarginBottom: 0;
}

.pf-c-options-menu__toggle:not(.pf-m-plain)::before,
.pf-c-options-menu.pf-m-text:not(.pf-m-plain) .pf-c-options-menu__toggle-button::before {
  position: absolute;
  top: 0;
  right: 0;
  bottom: 0;
  left: 0;
  content: "";
  border: var(--pf-c-options-menu__toggle--BorderWidth) solid;
  border-color: var(--pf-c-options-menu__toggle--BorderTopColor) var(--pf-c-options-menu__toggle--BorderRightColor) var(--pf-c-options-menu__toggle--BorderBottomColor) var(--pf-c-options-menu__toggle--BorderLeftColor);
}
.pf-c-options-menu__toggle:not(.pf-m-plain):hover::before,
.pf-c-options-menu.pf-m-text:not(.pf-m-plain) .pf-c-options-menu__toggle-button:hover::before {
  --pf-c-options-menu__toggle--BorderBottomColor: var(--pf-c-options-menu__toggle--hover--BorderBottomColor);
}
.pf-c-options-menu__toggle:not(.pf-m-plain):active::before, .pf-c-options-menu__toggle:not(.pf-m-plain).pf-m-active::before,
.pf-c-options-menu.pf-m-text:not(.pf-m-plain) .pf-c-options-menu__toggle-button:active::before,
.pf-c-options-menu.pf-m-text:not(.pf-m-plain) .pf-c-options-menu__toggle-button.pf-m-active::before {
  --pf-c-options-menu__toggle--BorderBottomColor: var(--pf-c-options-menu__toggle--active--BorderBottomColor);
  border-bottom-width: var(--pf-c-options-menu__toggle--active--BorderBottomWidth);
}
.pf-c-options-menu__toggle:not(.pf-m-plain):focus::before,
.pf-c-options-menu.pf-m-text:not(.pf-m-plain) .pf-c-options-menu__toggle-button:focus::before {
  --pf-c-options-menu__toggle--BorderBottomColor: var(--pf-c-options-menu__toggle--focus--BorderBottomColor);
  border-bottom-width: var(--pf-c-options-menu__toggle--focus--BorderBottomWidth);
}

.pf-c-options-menu__toggle {
  position: relative;
  display: flex;
  align-items: center;
  justify-content: space-between;
  min-width: var(--pf-c-options-menu__toggle--MinWidth);
  max-width: 100%;
  padding-left: var(--pf-c-options-menu__toggle--PaddingLeft);
  line-height: var(--pf-c-options-menu__toggle--LineHeight);
  color: var(--pf-c-options-menu__toggle--Color);
  background-color: var(--pf-c-options-menu__toggle--BackgroundColor);
  border: none;
}
.pf-c-options-menu__toggle:not(.pf-m-text) {
  padding-top: var(--pf-c-options-menu__toggle--PaddingTop);
  padding-right: var(--pf-c-options-menu__toggle--PaddingRight);
  padding-bottom: var(--pf-c-options-menu__toggle--PaddingBottom);
}
.pf-c-options-menu.pf-m-expanded > .pf-c-options-menu__toggle::before {
  --pf-c-options-menu__toggle--BorderBottomColor: var(--pf-c-options-menu__toggle--expanded--BorderBottomColor);
  border-bottom-width: var(--pf-c-options-menu__toggle--expanded--BorderBottomWidth);
}
.pf-c-options-menu__toggle.pf-m-plain {
  --pf-c-options-menu__toggle--PaddingRight: var(--pf-c-options-menu__toggle--m-plain--PaddingRight);
  --pf-c-options-menu__toggle--PaddingLeft: var(--pf-c-options-menu__toggle--m-plain--PaddingLeft);
  display: inline-block;
}
.pf-c-options-menu__toggle.pf-m-plain:not(.pf-m-text) {
  justify-content: center;
  color: var(--pf-c-options-menu__toggle--m-plain--Color);
}
.pf-c-options-menu__toggle.pf-m-plain .pf-c-options-menu__toggle-button-icon {
  line-height: var(--pf-c-options-menu__toggle--LineHeight);
}
.pf-c-options-menu__toggle.pf-m-plain:hover, .pf-c-options-menu__toggle.pf-m-plain:active, .pf-c-options-menu__toggle.pf-m-plain.pf-m-active, .pf-c-options-menu__toggle.pf-m-plain:focus, .pf-c-options-menu.pf-m-expanded > .pf-c-options-menu__toggle.pf-m-plain {
  --pf-c-options-menu__toggle--m-plain--Color: var(--pf-c-options-menu__toggle--m-plain--hover--Color);
}
.pf-c-options-menu__toggle.pf-m-plain.pf-m-disabled, .pf-c-options-menu__toggle.pf-m-plain:disabled {
  --pf-c-options-menu__toggle--m-plain--Color: var(--pf-c-options-menu__toggle--m-plain--disabled--Color);
}
.pf-c-options-menu__toggle.pf-m-disabled, .pf-c-options-menu__toggle:disabled {
  pointer-events: none;
}
.pf-c-options-menu__toggle.pf-m-disabled:not(.pf-m-plain), .pf-c-options-menu__toggle.pf-m-disabled.pf-m-text, .pf-c-options-menu__toggle:disabled:not(.pf-m-plain), .pf-c-options-menu__toggle:disabled.pf-m-text {
  --pf-c-options-menu__toggle--BackgroundColor: var(--pf-c-options-menu__toggle--disabled--BackgroundColor);
}
.pf-c-options-menu__toggle.pf-m-disabled::before, .pf-c-options-menu__toggle:disabled::before {
  border: 0;
}

.pf-c-options-menu__toggle-button-icon {
  position: relative;
}

.pf-c-options-menu__toggle-button {
  padding: var(--pf-c-options-menu__toggle-button--PaddingTop) var(--pf-c-options-menu__toggle-button--PaddingRight) var(--pf-c-options-menu__toggle-button--PaddingBottom) var(--pf-c-options-menu__toggle-button--PaddingLeft);
  background-color: var(--pf-c-options-menu__toggle-button--BackgroundColor);
  border: 0;
}

.pf-c-options-menu__toggle-text {
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
}

.pf-c-options-menu__toggle-icon {
  margin-right: var(--pf-c-options-menu__toggle-icon--MarginRight);
  margin-left: var(--pf-c-options-menu__toggle-icon--MarginLeft);
}
.pf-c-options-menu.pf-m-top.pf-m-expanded .pf-c-options-menu__toggle-icon {
  transform: rotate(var(--pf-c-options-menu--m-top--m-expanded__toggle-icon--Rotate));
}

.pf-c-options-menu__menu {
  position: absolute;
  top: var(--pf-c-options-menu__menu--Top);
  z-index: var(--pf-c-options-menu__menu--ZIndex);
  min-width: 100%;
  padding-top: var(--pf-c-options-menu__menu--PaddingTop);
  padding-bottom: var(--pf-c-options-menu__menu--PaddingBottom);
  background-color: var(--pf-c-options-menu__menu--BackgroundColor);
  background-clip: padding-box;
  box-shadow: var(--pf-c-options-menu__menu--BoxShadow);
}
.pf-c-options-menu__menu.pf-m-align-right {
  right: 0;
}
.pf-c-options-menu.pf-m-top .pf-c-options-menu__menu {
  --pf-c-options-menu__menu--Top: var(--pf-c-options-menu--m-top__menu--Top);
  transform: translateY(var(--pf-c-options-menu--m-top__menu--TranslateY));
}

.pf-c-options-menu__menu-item {
  display: flex;
  align-items: baseline;
  width: 100%;
  padding: var(--pf-c-options-menu__menu-item--PaddingTop) var(--pf-c-options-menu__menu-item--PaddingRight) var(--pf-c-options-menu__menu-item--PaddingBottom) var(--pf-c-options-menu__menu-item--PaddingLeft);
  font-size: var(--pf-c-options-menu__menu-item--FontSize);
  color: var(--pf-c-options-menu__menu-item--Color);
  white-space: nowrap;
  background-color: var(--pf-c-options-menu__menu-item--BackgroundColor);
  border: none;
}
.pf-c-options-menu__menu-item:hover, .pf-c-options-menu__menu-item:focus {
  text-decoration: none;
  background-color: var(--pf-c-options-menu__menu-item--hover--BackgroundColor);
}
.pf-c-options-menu__menu-item:disabled, .pf-c-options-menu__menu-item.pf-m-disabled {
  color: var(--pf-c-options-menu__menu-item--disabled--Color);
  pointer-events: none;
  background-color: var(--pf-c-options-menu__menu-item--disabled--BackgroundColor);
}

.pf-c-options-menu__menu-item-icon {
  align-self: center;
  width: auto;
  padding-left: var(--pf-c-options-menu__menu-item-icon--PaddingLeft);
  margin-left: auto;
  font-size: var(--pf-c-options-menu__menu-item-icon--FontSize);
  color: var(--pf-c-options-menu__menu-item-icon--Color);
}

.pf-c-options-menu__group + .pf-c-options-menu__group {
  padding-top: var(--pf-c-options-menu__group--group--PaddingTop);
}

.pf-c-options-menu__group-title {
  padding-top: var(--pf-c-options-menu__group-title--PaddingTop);
  padding-right: var(--pf-c-options-menu__group-title--PaddingRight);
  padding-bottom: var(--pf-c-options-menu__group-title--PaddingBottom);
  padding-left: var(--pf-c-options-menu__group-title--PaddingLeft);
  font-size: var(--pf-c-options-menu__group-title--FontSize);
  font-weight: var(--pf-c-options-menu__group-title--FontWeight);
  color: var(--pf-c-options-menu__group-title--Color);
}

.ins-c-pagination-next .pf-c-options-menu .pf-c-dropdown__menu .pf-c-dropdown__menu-item {
  display: flex;
}
.ins-c-pagination-next .pf-c-options-menu .pf-c-dropdown__menu .pf-c-dropdown__menu-item .pf-c-options-menu__menu-item-icon {
  padding-left: 0;
}

.pf-c-pagination .pf-c-pagination__nav .pf-c-pagination__nav-page-select input {
  width: 75px;
}

.ins-c-primary-toolbar .pf-c-toolbar__item.ins-c-primary-toolbar__first-action {
  display: initial;
}
.ins-c-primary-toolbar .ins-c-primary-toolbar__first-action {
  display: none;
}
.ins-c-primary-toolbar .ins-c-primary-toolbar__pagination {
  margin-left: auto;
}
.ins-c-primary-toolbar .ins-c-primary-toolbar__sort-by {
  display: initial;
}
.ins-c-primary-toolbar .ins-c-primary-toolbar__overflow-actions, .ins-c-primary-toolbar .ins-c-primary-toolbar__overflow-actions-separator {
  display: none;
}
.ins-c-primary-toolbar .ins-m-actions--empty {
  display: none;
}
.ins-c-primary-toolbar .ins-c-primary-toolbar__group-filter {
  flex-grow: initial;
}
.ins-c-primary-toolbar .ins-c-primary-toolbar__group-filter .ins-c-primary-toolbar__filter {
  flex: initial;
}

@media only screen and (max-width: 768px) {
  .ins-c-primary-toolbar .pf-c-toolbar__item.ins-c-primary-toolbar__first-action {
    display: none;
  }
  .ins-c-primary-toolbar .ins-c-primary-toolbar__first-action {
    display: block;
  }
  .ins-c-primary-toolbar .ins-c-primary-toolbar__sort-by {
    display: none;
  }
  .ins-c-primary-toolbar .ins-c-primary-toolbar__overflow-actions, .ins-c-primary-toolbar .ins-c-primary-toolbar__overflow-actions-separator {
    display: block;
  }
  .ins-c-primary-toolbar .ins-c-primary-toolbar__group-filter {
    margin-right: 0;
    flex-grow: 1;
  }
  .ins-c-primary-toolbar .ins-c-primary-toolbar__group-filter .ins-c-primary-toolbar__filter {
    flex: 1;
  }
  .ins-c-primary-toolbar .ins-m-actions--empty {
    display: block;
  }
}
:root {
  --ins-color--orange: #ec7a08;
}

.ins-c-reboot span {
  margin-left: 4px;
  margin-left: 0.25rem;
}
.ins-c-reboot.ins-m-red span, .ins-c-reboot.ins-m-red svg {
  color: var(--pf-global--danger-color--100);
}

:root {
  --ins-color--orange: #ec7a08;
}

section.ins-l-content {
  padding: var(--pf-global--spacer--lg);
}

section.ins-l-button-group {
  margin: 24px 0px;
  margin: 1.5rem 0rem;
}
section.ins-l-button-group > * {
  display: inline;
}
section.ins-l-button-group * + * {
  margin-left: 5px;
  margin-left: 0.3125rem;
}

section.ins-l-icon-group * + * {
  margin-left: 10px;
}

section.ins-l-icon-group__with-major * + * {
  margin-left: 7.5px;
}
section.ins-l-icon-group__with-major .ins-battery:last-of-type {
  padding-left: 15px;
  border-left: 2px solid #eaeaea;
}
section.ins-l-icon-group__with-major .ins-battery:last-of-type span.label {
  font-weight: 500;
  margin: 0 10px;
}

.pf-c-form-control, .pf-c-input-group {
  --pf-global--Color--100: var(--pf-global--Color--dark-100);
  --pf-global--Color--200: var(--pf-global--Color--dark-200);
  --pf-global--BorderColor--100: var(--pf-global--BorderColor--dark-100);
  --pf-global--primary-color--100: var(--pf-global--primary-color--dark-100);
  --pf-global--link--Color: var(--pf-global--link--Color--dark);
  --pf-global--link--Color--hover: var(--pf-global--link--Color--dark--hover);
  --pf-global--BackgroundColor--100: var(--pf-global--BackgroundColor--light-100);
}

.pf-c-input-group {
  --pf-c-input-group--BackgroundColor: var(--pf-global--BackgroundColor--100);
  --pf-c-input-group--child--ZIndex: var(--pf-global--ZIndex--xs);
  --pf-c-input-group__text--FontSize: var(--pf-global--FontSize--md);
  --pf-c-input-group__text--PaddingRight: var(--pf-global--spacer--sm);
  --pf-c-input-group__text--PaddingLeft: var(--pf-global--spacer--sm);
  --pf-c-input-group__text--Color: var(--pf-global--Color--dark-200);
  --pf-c-input-group__text--BorderWidth: var(--pf-global--BorderWidth--sm);
  --pf-c-input-group__text--BorderTopColor: var(--pf-global--BorderColor--300);
  --pf-c-input-group__text--BorderRightColor: var(--pf-global--BorderColor--300);
  --pf-c-input-group__text--BorderBottomColor: var(--pf-global--BorderColor--200);
  --pf-c-input-group__text--BorderLeftColor: var(--pf-global--BorderColor--300);
  --pf-c-input-group__text--BackgroundColor: var(--pf-global--BackgroundColor--100);
  --pf-c-input-group__textarea--MinHeight: var(--pf-global--spacer--xl);
  --pf-c-input-group--c-form-control--invalid--ZIndex: var(--pf-global--ZIndex--xs);
  --pf-c-input-group--c-form-control--MarginRight: 0;
  color: var(--pf-global--Color--100);
  display: flex;
  width: 100%;
  background-color: var(--pf-c-input-group--BackgroundColor);
}
.pf-c-input-group > * + * {
  margin-left: -1px;
}
.pf-c-input-group > :focus,
.pf-c-input-group > :focus-within {
  z-index: var(--pf-c-input-group--child--ZIndex);
}
.pf-c-input-group .pf-c-form-control[aria-invalid=true]:not(:last-child) {
  margin-right: var(--pf-c-input-group--c-form-control--MarginRight);
}
.pf-c-input-group input:not([type=checkbox]):not([type=radio]),
.pf-c-input-group textarea {
  flex: 2;
  min-width: 0;
}
.pf-c-input-group textarea {
  min-height: var(--pf-c-input-group__textarea--MinHeight);
}

.pf-c-input-group__text {
  display: flex;
  align-items: center;
  padding-right: var(--pf-c-input-group__text--PaddingRight);
  padding-left: var(--pf-c-input-group__text--PaddingLeft);
  font-size: var(--pf-c-input-group__text--FontSize);
  color: var(--pf-c-input-group__text--Color);
  text-align: center;
  background-color: var(--pf-c-input-group__text--BackgroundColor);
  border: var(--pf-c-input-group__text--BorderWidth) solid;
  border-color: var(--pf-c-input-group__text--BorderTopColor) var(--pf-c-input-group__text--BorderRightColor) var(--pf-c-input-group__text--BorderBottomColor) var(--pf-c-input-group__text--BorderLeftColor);
}
label.pf-c-input-group__text {
  cursor: pointer;
}

.pf-c-input-group__text.pf-m-plain {
  --pf-c-input-group__text--BorderWidth: 0;
  margin-left: 0;
}

.pf-c-form-control {
  --pf-c-form-control--FontSize: var(--pf-global--FontSize--md);
  --pf-c-form-control--LineHeight: var(--pf-global--LineHeight--md);
  --pf-c-form-control--BorderWidth: var(--pf-global--BorderWidth--sm);
  --pf-c-form-control--BorderTopColor: var(--pf-global--BorderColor--300);
  --pf-c-form-control--BorderRightColor: var(--pf-global--BorderColor--300);
  --pf-c-form-control--BorderBottomColor: var(--pf-global--BorderColor--200);
  --pf-c-form-control--BorderLeftColor: var(--pf-global--BorderColor--300);
  --pf-c-form-control--BorderRadius: 0;
  --pf-c-form-control--BackgroundColor: var(--pf-global--BackgroundColor--100);
  --pf-c-form-control--Width: 100%;
  --pf-c-form-control--Height: calc(var(--pf-c-form-control--FontSize) * var(--pf-c-form-control--LineHeight) + var(--pf-c-form-control--BorderWidth) * 2 + var(--pf-c-form-control--PaddingTop) + var(--pf-c-form-control--PaddingBottom));
  --pf-c-form-control--inset--base: var(--pf-global--spacer--sm);
  --pf-c-form-control--PaddingTop: calc(var(--pf-global--spacer--form-element) - var(--pf-global--BorderWidth--sm));
  --pf-c-form-control--PaddingBottom: calc(var(--pf-global--spacer--form-element) - var(--pf-global--BorderWidth--sm));
  --pf-c-form-control--PaddingRight: var(--pf-c-form-control--inset--base);
  --pf-c-form-control--PaddingLeft: var(--pf-c-form-control--inset--base);
  --pf-c-form-control--hover--BorderBottomColor: var(--pf-global--primary-color--100);
  --pf-c-form-control--focus--BorderBottomWidth: var(--pf-global--BorderWidth--md);
  --pf-c-form-control--focus--PaddingBottom: calc(var(--pf-global--spacer--form-element) - var(--pf-c-form-control--focus--BorderBottomWidth));
  --pf-c-form-control--focus--BorderBottomColor: var(--pf-global--primary-color--100);
  --pf-c-form-control--m-expanded--BorderBottomWidth: var(--pf-global--BorderWidth--md);
  --pf-c-form-control--m-expanded--PaddingBottom: calc(var(--pf-global--spacer--form-element) - var(--pf-c-form-control--focus--BorderBottomWidth));
  --pf-c-form-control--m-expanded--BorderBottomColor: var(--pf-global--primary-color--100);
  --pf-c-form-control--placeholder--Color: var(--pf-global--Color--dark-200);
  --pf-c-form-control--disabled--Color: var(--pf-global--disabled-color--100);
  --pf-c-form-control--disabled--BackgroundColor: var(--pf-global--disabled-color--300);
  --pf-c-form-control--disabled--BorderColor: transparent;
  --pf-c-form-control--readonly--BackgroundColor: var(--pf-global--disabled-color--300);
  --pf-c-form-control--readonly--hover--BorderBottomColor: var(--pf-global--BorderColor--200);
  --pf-c-form-control--readonly--focus--PaddingBottom: calc(var(--pf-global--spacer--form-element) - var(--pf-global--BorderWidth--sm));
  --pf-c-form-control--readonly--focus--BorderBottomWidth: var(--pf-global--BorderWidth--sm);
  --pf-c-form-control--readonly--focus--BorderBottomColor: var(--pf-global--BorderColor--200);
  --pf-c-form-control--success--BorderBottomWidth: var(--pf-global--BorderWidth--md);
  --pf-c-form-control--success--PaddingBottom: calc(var(--pf-global--spacer--form-element) - var(--pf-c-form-control--success--BorderBottomWidth));
  --pf-c-form-control--success--BorderBottomColor: var(--pf-global--success-color--100);
  --pf-c-form-control--success--PaddingRight: var(--pf-global--spacer--xl);
  --pf-c-form-control--success--BackgroundPositionX: calc(100% - var(--pf-c-form-control--PaddingLeft));
  --pf-c-form-control--success--BackgroundPositionY: center;
  --pf-c-form-control--success--BackgroundPosition: var(--pf-c-form-control--success--BackgroundPositionX) var(--pf-c-form-control--success--BackgroundPositionY);
  --pf-c-form-control--success--BackgroundSizeX: var(--pf-c-form-control--FontSize);
  --pf-c-form-control--success--BackgroundSizeY: var(--pf-c-form-control--FontSize);
  --pf-c-form-control--success--BackgroundSize: var(--pf-c-form-control--success--BackgroundSizeX) var(--pf-c-form-control--success--BackgroundSizeY);
  --pf-c-form-control--success--BackgroundUrl: url("data:image/svg+xml;charset=utf8,%3Csvg xmlns=%27http://www.w3.org/2000/svg%27 viewBox=%270 0 512 512%27%3E%3Cpath fill=%27%233e8635%27 d=%27M504 256c0 136.967-111.033 248-248 248S8 392.967 8 256 119.033 8 256 8s248 111.033 248 248zM227.314 387.314l184-184c6.248-6.248 6.248-16.379 0-22.627l-22.627-22.627c-6.248-6.249-16.379-6.249-22.628 0L216 308.118l-70.059-70.059c-6.248-6.248-16.379-6.248-22.628 0l-22.627 22.627c-6.248 6.248-6.248 16.379 0 22.627l104 104c6.249 6.249 16.379 6.249 22.628.001z%27/%3E%3C/svg%3E");
  --pf-c-form-control--m-warning--BorderBottomWidth: var(--pf-global--BorderWidth--md);
  --pf-c-form-control--m-warning--PaddingBottom: calc(var(--pf-global--spacer--form-element) - var(--pf-c-form-control--m-warning--BorderBottomWidth));
  --pf-c-form-control--m-warning--BorderBottomColor: var(--pf-global--warning-color--100);
  --pf-c-form-control--m-warning--PaddingRight: var(--pf-global--spacer--xl);
  --pf-c-form-control--m-warning--BackgroundPositionX: calc(100% - calc(var(--pf-c-form-control--PaddingLeft) - 0.0625rem));
  --pf-c-form-control--m-warning--BackgroundPositionY: center;
  --pf-c-form-control--m-warning--BackgroundPosition: var(--pf-c-form-control--m-warning--BackgroundPositionX) var(--pf-c-form-control--m-warning--BackgroundPositionY);
  --pf-c-form-control--m-warning--BackgroundSizeX: 1.25rem;
  --pf-c-form-control--m-warning--BackgroundSizeY: var(--pf-c-form-control--FontSize);
  --pf-c-form-control--m-warning--BackgroundSize: var(--pf-c-form-control--m-warning--BackgroundSizeX) var(--pf-c-form-control--m-warning--BackgroundSizeY);
  --pf-c-form-control--m-warning--BackgroundUrl: url("data:image/svg+xml;charset=utf8,%3Csvg xmlns=%27http://www.w3.org/2000/svg%27 viewBox=%270 0 512 512%27%3E%3Cpath fill=%27%23f0ab00%27 d=%27M569.517 440.013C587.975 472.007 564.806 512 527.94 512H48.054c-36.937 0-59.999-40.055-41.577-71.987L246.423 23.985c18.467-32.009 64.72-31.951 83.154 0l239.94 416.028zM288 354c-25.405 0-46 20.595-46 46s20.595 46 46 46 46-20.595 46-46-20.595-46-46-46zm-43.673-165.346l7.418 136c.347 6.364 5.609 11.346 11.982 11.346h48.546c6.373 0 11.635-4.982 11.982-11.346l7.418-136c.375-6.874-5.098-12.654-11.982-12.654h-63.383c-6.884 0-12.356 5.78-11.981 12.654z%27/%3E%3C/svg%3E");
  --pf-c-form-control--invalid--BorderBottomWidth: var(--pf-global--BorderWidth--md);
  --pf-c-form-control--invalid--PaddingBottom: calc(var(--pf-global--spacer--form-element) - var(--pf-c-form-control--invalid--BorderBottomWidth));
  --pf-c-form-control--invalid--BorderBottomColor: var(--pf-global--danger-color--100);
  --pf-c-form-control--invalid--PaddingRight: var(--pf-global--spacer--xl);
  --pf-c-form-control--invalid--BackgroundPositionX: calc(100% - var(--pf-c-form-control--PaddingLeft));
  --pf-c-form-control--invalid--BackgroundPositionY: center;
  --pf-c-form-control--invalid--BackgroundPosition: var(--pf-c-form-control--invalid--BackgroundPositionX) var(--pf-c-form-control--invalid--BackgroundPositionY);
  --pf-c-form-control--invalid--BackgroundSizeX: var(--pf-c-form-control--FontSize);
  --pf-c-form-control--invalid--BackgroundSizeY: var(--pf-c-form-control--FontSize);
  --pf-c-form-control--invalid--BackgroundSize: var(--pf-c-form-control--invalid--BackgroundSizeX) var(--pf-c-form-control--invalid--BackgroundSizeY);
  --pf-c-form-control--invalid--BackgroundUrl: url("data:image/svg+xml;charset=utf8,%3Csvg xmlns=%27http://www.w3.org/2000/svg%27 viewBox=%270 0 512 512%27%3E%3Cpath fill=%27%23c9190b%27 d=%27M504 256c0 136.997-111.043 248-248 248S8 392.997 8 256C8 119.083 119.043 8 256 8s248 111.083 248 248zm-248 50c-25.405 0-46 20.595-46 46s20.595 46 46 46 46-20.595 46-46-20.595-46-46-46zm-43.673-165.346l7.418 136c.347 6.364 5.609 11.346 11.982 11.346h48.546c6.373 0 11.635-4.982 11.982-11.346l7.418-136c.375-6.874-5.098-12.654-11.982-12.654h-63.383c-6.884 0-12.356 5.78-11.981 12.654z%27/%3E%3C/svg%3E");
  --pf-c-form-control--invalid--exclamation--Background: var(--pf-c-form-control--invalid--BackgroundUrl) var(--pf-c-form-control--invalid--BackgroundPosition) / var(--pf-c-form-control--invalid--BackgroundSize) no-repeat;
  --pf-c-form-control--invalid--Background: var(--pf-c-form-control--BackgroundColor) var(--pf-c-form-control--invalid--exclamation--Background);
  --pf-c-form-control--m-search--PaddingLeft: var(--pf-global--spacer--xl);
  --pf-c-form-control--m-search--BackgroundPosition: var(--pf-c-form-control--PaddingRight);
  --pf-c-form-control--m-search--BackgroundSize: var(--pf-c-form-control--FontSize) var(--pf-c-form-control--FontSize);
  --pf-c-form-control--m-search--BackgroundUrl: url("data:image/svg+xml;charset=utf8,%3Csvg xmlns=%27http://www.w3.org/2000/svg%27 viewBox=%270 0 512 512%27%3E%3Cpath fill=%27%236a6e73%27 d=%27M505 442.7L405.3 343c-4.5-4.5-10.6-7-17-7H372c27.6-35.3 44-79.7 44-128C416 93.1 322.9 0 208 0S0 93.1 0 208s93.1 208 208 208c48.3 0 92.7-16.4 128-44v16.3c0 6.4 2.5 12.5 7 17l99.7 99.7c9.4 9.4 24.6 9.4 33.9 0l28.3-28.3c9.4-9.4 9.4-24.6.1-34zM208 336c-70.7 0-128-57.2-128-128 0-70.7 57.2-128 128-128 70.7 0 128 57.2 128 128 0 70.7-57.2 128-128 128z%27/%3E%3C/svg%3E");
  --pf-c-form-control--m-icon--PaddingRight: calc(var(--pf-c-form-control--inset--base) + var(--pf-c-form-control--m-icon--BackgroundSizeX) + var(--pf-c-form-control--m-icon--icon--spacer));
  --pf-c-form-control--m-icon--BackgroundUrl: none;
  --pf-c-form-control--m-icon--BackgroundPositionX: calc(100% - var(--pf-c-form-control--inset--base));
  --pf-c-form-control--m-icon--BackgroundPositionY: center;
  --pf-c-form-control--m-icon--BackgroundSizeX: var(--pf-c-form-control--FontSize);
  --pf-c-form-control--m-icon--BackgroundSizeY: var(--pf-c-form-control--FontSize);
  --pf-c-form-control--m-icon--icon--spacer: var(--pf-global--spacer--sm);
  --pf-c-form-control--m-icon--icon--PaddingRight: calc(var(--pf-c-form-control--inset--base) + var(--pf-c-form-control--invalid--BackgroundSizeX) + var(--pf-c-form-control--m-icon--icon--spacer) + var(--pf-c-form-control--m-icon--BackgroundSizeX) + var(--pf-c-form-control--m-icon--icon--spacer));
  --pf-c-form-control--m-icon--icon--BackgroundPositionX: calc(var(--pf-c-form-control--m-icon--BackgroundPositionX) - var(--pf-c-form-control--m-icon--icon--spacer) - var(--pf-c-form-control--invalid--BackgroundSizeX));
  --pf-c-form-control--m-icon--invalid--BackgroundUrl: var(--pf-c-form-control--invalid--BackgroundUrl), var(--pf-c-form-control--m-icon--BackgroundUrl);
  --pf-c-form-control--m-icon--invalid--BackgroundPosition: var(--pf-c-form-control--invalid--BackgroundPosition), var(--pf-c-form-control--m-icon--icon--BackgroundPositionX) var(--pf-c-form-control--m-icon--BackgroundPositionY);
  --pf-c-form-control--m-icon--invalid--BackgroundSize: var(--pf-c-form-control--invalid--BackgroundSize), var(--pf-c-form-control--m-icon--BackgroundSizeX) var(--pf-c-form-control--m-icon--BackgroundSizeY);
  --pf-c-form-control--m-icon--success--BackgroundUrl: var(--pf-c-form-control--success--BackgroundUrl), var(--pf-c-form-control--m-icon--BackgroundUrl);
  --pf-c-form-control--m-icon--success--BackgroundPosition: var(--pf-c-form-control--success--BackgroundPosition), var(--pf-c-form-control--m-icon--icon--BackgroundPositionX) var(--pf-c-form-control--m-icon--BackgroundPositionY);
  --pf-c-form-control--m-icon--success--BackgroundSize: var(--pf-c-form-control--success--BackgroundSize), var(--pf-c-form-control--m-icon--BackgroundSizeX) var(--pf-c-form-control--m-icon--BackgroundSizeY);
  --pf-c-form-control--m-icon--m-warning--BackgroundUrl: var(--pf-c-form-control--m-warning--BackgroundUrl), var(--pf-c-form-control--m-icon--BackgroundUrl);
  --pf-c-form-control--m-icon--m-warning--BackgroundPosition: var(--pf-c-form-control--m-warning--BackgroundPosition), var(--pf-c-form-control--m-icon--icon--BackgroundPositionX) var(--pf-c-form-control--m-icon--BackgroundPositionY);
  --pf-c-form-control--m-icon--m-warning--BackgroundSize: var(--pf-c-form-control--m-warning--BackgroundSize), var(--pf-c-form-control--m-icon--BackgroundSizeX) var(--pf-c-form-control--m-icon--BackgroundSizeY);
  --pf-c-form-control--m-calendar--BackgroundUrl: url("data:image/svg+xml;charset=utf8,%3Csvg xmlns=%27http://www.w3.org/2000/svg%27 viewBox=%270 0 512 512%27%3E%3Cpath fill=%27%236a6e73%27 d=%27M0 464c0 26.5 21.5 48 48 48h352c26.5 0 48-21.5 48-48V192H0v272zm320-196c0-6.6 5.4-12 12-12h40c6.6 0 12 5.4 12 12v40c0 6.6-5.4 12-12 12h-40c-6.6 0-12-5.4-12-12v-40zm0 128c0-6.6 5.4-12 12-12h40c6.6 0 12 5.4 12 12v40c0 6.6-5.4 12-12 12h-40c-6.6 0-12-5.4-12-12v-40zM192 268c0-6.6 5.4-12 12-12h40c6.6 0 12 5.4 12 12v40c0 6.6-5.4 12-12 12h-40c-6.6 0-12-5.4-12-12v-40zm0 128c0-6.6 5.4-12 12-12h40c6.6 0 12 5.4 12 12v40c0 6.6-5.4 12-12 12h-40c-6.6 0-12-5.4-12-12v-40zM64 268c0-6.6 5.4-12 12-12h40c6.6 0 12 5.4 12 12v40c0 6.6-5.4 12-12 12H76c-6.6 0-12-5.4-12-12v-40zm0 128c0-6.6 5.4-12 12-12h40c6.6 0 12 5.4 12 12v40c0 6.6-5.4 12-12 12H76c-6.6 0-12-5.4-12-12v-40zM400 64h-48V16c0-8.8-7.2-16-16-16h-32c-8.8 0-16 7.2-16 16v48H160V16c0-8.8-7.2-16-16-16h-32c-8.8 0-16 7.2-16 16v48H48C21.5 64 0 85.5 0 112v48h448v-48c0-26.5-21.5-48-48-48z%27/%3E%3C/svg%3E");
  --pf-c-form-control--m-clock--BackgroundUrl: url("data:image/svg+xml;charset=utf8,%3Csvg xmlns=%27http://www.w3.org/2000/svg%27 viewBox=%270 0 512 512%27%3E%3Cpath fill=%27%236a6e73%27 d=%27M256 8C119 8 8 119 8 256s111 248 248 248 248-111 248-248S393 8 256 8zm0 448c-110.5 0-200-89.5-200-200S145.5 56 256 56s200 89.5 200 200-89.5 200-200 200zm61.8-104.4l-84.9-61.7c-3.1-2.3-4.9-5.9-4.9-9.7V116c0-6.6 5.4-12 12-12h32c6.6 0 12 5.4 12 12v141.7l66.8 48.6c5.4 3.9 6.5 11.4 2.6 16.8L334.6 349c-3.9 5.3-11.4 6.5-16.8 2.6z%27/%3E%3C/svg%3E");
  --pf-c-form-control__select--PaddingRight: var(--pf-global--spacer--lg);
  --pf-c-form-control__select--BackgroundUrl: url("data:image/svg+xml;charset=utf8,%3Csvg xmlns=%27http://www.w3.org/2000/svg%27 viewBox=%270 0 320 512%27%3E%3Cpath fill=%27%23urrentColor%27 d=%27M31.3 192h257.3c17.8 0 26.7 21.5 14.1 34.1L174.1 354.8c-7.8 7.8-20.5 7.8-28.3 0L17.2 226.1C4.6 213.5 13.5 192 31.3 192z%27/%3E%3C/svg%3E");
  --pf-c-form-control__select--BackgroundSize: .625em;
  --pf-c-form-control__select--BackgroundPositionX: calc(100% - var(--pf-global--spacer--md) + 1px);
  --pf-c-form-control__select--BackgroundPositionY: center;
  --pf-c-form-control__select--BackgroundPosition: var(--pf-c-form-control__select--BackgroundPositionX) var(--pf-c-form-control__select--BackgroundPositionY);
  --pf-c-form-control__select--success--PaddingRight: var(--pf-global--spacer--3xl);
  --pf-c-form-control__select--success--BackgroundPosition: calc(var(--pf-c-form-control__select--BackgroundPositionX) - var(--pf-global--spacer--lg));
  --pf-c-form-control__select--m-warning--PaddingRight: var(--pf-global--spacer--3xl);
  --pf-c-form-control__select--m-warning--BackgroundPosition: calc(var(--pf-c-form-control__select--BackgroundPositionX) - var(--pf-global--spacer--lg) + 0.0625rem);
  --pf-c-form-control__select--invalid--PaddingRight: var(--pf-global--spacer--3xl);
  --pf-c-form-control__select--invalid--BackgroundPosition: calc(var(--pf-c-form-control__select--BackgroundPositionX) - var(--pf-global--spacer--lg));
  --pf-c-form-control--textarea--Width: var(--pf-c-form-control--Width);
  --pf-c-form-control--textarea--Height: auto;
  --pf-c-form-control--textarea--success--BackgroundPositionY: var(--pf-c-form-control--PaddingLeft);
  --pf-c-form-control--textarea--m-warning--BackgroundPositionY: var(--pf-c-form-control--PaddingLeft);
  --pf-c-form-control--textarea--invalid--BackgroundPositionY: var(--pf-c-form-control--PaddingLeft);
  color: var(--pf-global--Color--100);
  width: var(--pf-c-form-control--Width);
  padding: var(--pf-c-form-control--PaddingTop) var(--pf-c-form-control--PaddingRight) var(--pf-c-form-control--PaddingBottom) var(--pf-c-form-control--PaddingLeft);
  font-size: var(--pf-c-form-control--FontSize);
  line-height: var(--pf-c-form-control--LineHeight);
  background-color: var(--pf-c-form-control--BackgroundColor);
  background-repeat: no-repeat;
  border: var(--pf-c-form-control--BorderWidth) solid;
  border-color: var(--pf-c-form-control--BorderTopColor) var(--pf-c-form-control--BorderRightColor) var(--pf-c-form-control--BorderBottomColor) var(--pf-c-form-control--BorderLeftColor);
  border-radius: var(--pf-c-form-control--BorderRadius);
  -moz-appearance: none;
  -webkit-appearance: none;
}
.pf-c-form-control::placeholder {
  color: var(--pf-c-form-control--placeholder--Color);
}
.pf-c-form-control:not(textarea) {
  height: var(--pf-c-form-control--Height);
  text-overflow: ellipsis;
}
.pf-c-form-control[readonly] {
  background-color: var(--pf-c-form-control--readonly--BackgroundColor);
}
.pf-c-form-control[readonly]:not(.pf-m-success):not([aria-invalid=true]):hover {
  --pf-c-form-control--BorderBottomColor: var(--pf-c-form-control--readonly--hover--BorderBottomColor);
}
.pf-c-form-control[readonly]:not(.pf-m-success):not([aria-invalid=true]):focus {
  --pf-c-form-control--focus--PaddingBottom: var(--pf-c-form-control--readonly--focus--PaddingBottom);
  --pf-c-form-control--focus--BorderBottomWidth: var(--pf-c-form-control--readonly--focus--BorderBottomWidth);
  --pf-c-form-control--focus--BorderBottomColor: var(--pf-c-form-control--readonly--focus--BorderBottomColor);
}
.pf-c-form-control:hover {
  --pf-c-form-control--BorderBottomColor: var(--pf-c-form-control--hover--BorderBottomColor);
}
.pf-c-form-control:focus {
  --pf-c-form-control--BorderBottomColor: var(--pf-c-form-control--focus--BorderBottomColor);
  padding-bottom: var(--pf-c-form-control--focus--PaddingBottom);
  border-bottom-width: var(--pf-c-form-control--focus--BorderBottomWidth);
}
.pf-c-form-control.pf-m-expanded {
  --pf-c-form-control--BorderBottomColor: var(--pf-c-form-control--m-expanded--BorderBottomColor);
  padding-bottom: var(--pf-c-form-control--m-expanded--PaddingBottom);
  border-bottom-width: var(--pf-c-form-control--m-expanded--BorderBottomWidth);
}
.pf-c-form-control:disabled {
  --pf-c-form-control--Color: var(--pf-c-form-control--disabled--Color);
  --pf-c-form-control--BackgroundColor: var(--pf-c-form-control--disabled--BackgroundColor);
  cursor: not-allowed;
  border-color: var(--pf-c-form-control--disabled--BorderColor);
}
.pf-c-form-control[aria-invalid=true] {
  --pf-c-form-control--PaddingRight: var(--pf-c-form-control--invalid--PaddingRight);
  --pf-c-form-control--BorderBottomColor: var(--pf-c-form-control--invalid--BorderBottomColor);
  padding-bottom: var(--pf-c-form-control--invalid--PaddingBottom);
  background-image: var(--pf-c-form-control--invalid--BackgroundUrl);
  background-position: var(--pf-c-form-control--invalid--BackgroundPosition);
  background-size: var(--pf-c-form-control--invalid--BackgroundSize);
  border-bottom-width: var(--pf-c-form-control--invalid--BorderBottomWidth);
}
.pf-c-form-control[aria-invalid=true].pf-m-icon {
  --pf-c-form-control--PaddingRight: var(--pf-c-form-control--m-icon--icon--PaddingRight);
  background-image: var(--pf-c-form-control--m-icon--invalid--BackgroundUrl);
  background-position: var(--pf-c-form-control--m-icon--invalid--BackgroundPosition);
  background-size: var(--pf-c-form-control--m-icon--invalid--BackgroundSize);
}
.pf-c-form-control.pf-m-success {
  --pf-c-form-control--PaddingRight: var(--pf-c-form-control--success--PaddingRight);
  --pf-c-form-control--BorderBottomColor: var(--pf-c-form-control--success--BorderBottomColor);
  padding-bottom: var(--pf-c-form-control--success--PaddingBottom);
  background-image: var(--pf-c-form-control--success--BackgroundUrl);
  background-position: var(--pf-c-form-control--success--BackgroundPosition);
  background-size: var(--pf-c-form-control--success--BackgroundSize);
  border-bottom-width: var(--pf-c-form-control--success--BorderBottomWidth);
}
.pf-c-form-control.pf-m-success.pf-m-icon {
  --pf-c-form-control--PaddingRight: var(--pf-c-form-control--m-icon--icon--PaddingRight);
  background-image: var(--pf-c-form-control--m-icon--success--BackgroundUrl);
  background-position: var(--pf-c-form-control--m-icon--success--BackgroundPosition);
  background-size: var(--pf-c-form-control--m-icon--success--BackgroundSize);
}
.pf-c-form-control.pf-m-warning {
  --pf-c-form-control--PaddingRight: var(--pf-c-form-control--m-warning--PaddingRight);
  --pf-c-form-control--BorderBottomColor: var(--pf-c-form-control--m-warning--BorderBottomColor);
  padding-bottom: var(--pf-c-form-control--m-warning--PaddingBottom);
  background-image: var(--pf-c-form-control--m-warning--BackgroundUrl);
  background-position: var(--pf-c-form-control--m-warning--BackgroundPosition);
  background-size: var(--pf-c-form-control--m-warning--BackgroundSize);
  border-bottom-width: var(--pf-c-form-control--m-warning--BorderBottomWidth);
}
.pf-c-form-control.pf-m-warning.pf-m-icon {
  --pf-c-form-control--PaddingRight: var(--pf-c-form-control--m-icon--icon--PaddingRight);
  background-image: var(--pf-c-form-control--m-icon--m-warning--BackgroundUrl);
  background-position: var(--pf-c-form-control--m-icon--m-warning--BackgroundPosition);
  background-size: var(--pf-c-form-control--m-icon--m-warning--BackgroundSize);
}
.pf-c-form-control.pf-m-search {
  --pf-c-form-control--PaddingLeft: var(--pf-c-form-control--m-search--PaddingLeft);
  background-image: var(--pf-c-form-control--m-search--BackgroundUrl);
  background-position: var(--pf-c-form-control--m-search--BackgroundPosition);
  background-size: var(--pf-c-form-control--m-search--BackgroundSize);
}
.pf-c-form-control.pf-m-icon {
  --pf-c-form-control--PaddingRight: var(--pf-c-form-control--m-icon--PaddingRight);
  background-image: var(--pf-c-form-control--m-icon--BackgroundUrl);
  background-position: var(--pf-c-form-control--m-icon--BackgroundPositionX) var(--pf-c-form-control--m-icon--BackgroundPositionY);
  background-size: var(--pf-c-form-control--m-icon--BackgroundSizeX) var(--pf-c-form-control--m-icon--BackgroundSizeY);
}
.pf-c-form-control.pf-m-icon.pf-m-calendar {
  --pf-c-form-control--m-icon--BackgroundUrl: var(--pf-c-form-control--m-calendar--BackgroundUrl);
}
.pf-c-form-control.pf-m-icon.pf-m-clock {
  --pf-c-form-control--m-icon--BackgroundUrl: var(--pf-c-form-control--m-clock--BackgroundUrl);
}
select.pf-c-form-control {
  --pf-c-form-control--PaddingRight: var(--pf-c-form-control__select--PaddingRight);
  background-image: var(--pf-c-form-control__select--BackgroundUrl);
  background-position: var(--pf-c-form-control__select--BackgroundPosition);
  background-size: var(--pf-c-form-control__select--BackgroundSize);
}
select.pf-c-form-control[aria-invalid=true] {
  --pf-c-form-control--PaddingRight: var(--pf-c-form-control__select--invalid--PaddingRight);
  --pf-c-form-control--invalid--BackgroundPosition: var(--pf-c-form-control__select--invalid--BackgroundPosition);
  background-image: var(--pf-c-form-control__select--BackgroundUrl), var(--pf-c-form-control--invalid--BackgroundUrl);
  background-position: var(--pf-c-form-control__select--BackgroundPosition), var(--pf-c-form-control--invalid--BackgroundPosition);
  background-size: var(--pf-c-form-control__select--BackgroundSize), var(--pf-c-form-control--invalid--BackgroundSize);
}
select.pf-c-form-control.pf-m-success {
  --pf-c-form-control--PaddingRight: var(--pf-c-form-control__select--success--PaddingRight);
  --pf-c-form-control--success--BackgroundPosition: var(--pf-c-form-control__select--success--BackgroundPosition);
  background-image: var(--pf-c-form-control__select--BackgroundUrl), var(--pf-c-form-control--success--BackgroundUrl);
  background-position: var(--pf-c-form-control__select--BackgroundPosition), var(--pf-c-form-control--success--BackgroundPosition);
  background-size: var(--pf-c-form-control__select--BackgroundSize), var(--pf-c-form-control--success--BackgroundSize);
}
select.pf-c-form-control.pf-m-warning {
  --pf-c-form-control--PaddingRight: var(--pf-c-form-control__select--m-warning--PaddingRight);
  background-image: var(--pf-c-form-control__select--BackgroundUrl), var(--pf-c-form-control--m-warning--BackgroundUrl);
  background-position: var(--pf-c-form-control__select--BackgroundPosition), var(--pf-c-form-control__select--m-warning--BackgroundPosition);
  background-size: var(--pf-c-form-control__select--BackgroundSize), var(--pf-c-form-control--m-warning--BackgroundSize);
}
select.pf-c-form-control.pf-m-placeholder {
  color: var(--pf-c-form-control--placeholder--Color);
}

textarea.pf-c-form-control {
  --pf-c-form-control--success--BackgroundPositionY: var(--pf-c-form-control--textarea--success--BackgroundPositionY);
  --pf-c-form-control--invalid--BackgroundPositionY: var(--pf-c-form-control--textarea--invalid--BackgroundPositionY);
  --pf-c-form-control--m-warning--BackgroundPositionY: var(--pf-c-form-control--textarea--m-warning--BackgroundPositionY);
  width: var(--pf-c-form-control--textarea--Width);
  height: var(--pf-c-form-control--textarea--Height);
}

.pf-c-form-control.pf-m-resize-vertical {
  resize: vertical;
}
.pf-c-form-control.pf-m-resize-horizontal {
  resize: horizontal;
}

:root {
  --ins-color--orange: #ec7a08;
}

.pf-c-input-group.ins-c-filter.ins-u-no-title input {
  padding-right: 35px;
  padding-right: 2.1875rem;
  margin-right: -23px;
  margin-right: -1.4375rem;
}
.pf-c-input-group.ins-c-filter .ins-c-search-icon {
  color: var(--pf-global--secondary-color--100);
  position: relative;
  left: -5px;
  left: -0.3125rem;
  top: 8px;
  top: 0.5rem;
}

:root {
  --ins-color--orange: #ec7a08;
}

.ins-c-skeleton {
  animation-duration: 1s;
  animation-iteration-count: infinite;
  animation-name: skeletonGradient;
  animation-timing-function: linear;
  background: var(--pf-global--disabled-color--200);
  background: linear-gradient(to right, #f5f5f5 10%, #e8e8e8 18%, #f5f5f5 33%);
  background-size: 1000px 50px;
  background-size: 62.5rem 3.125rem;
  border-radius: 5px;
  border-radius: 0.3125rem;
}
.ins-c-skeleton__xs {
  width: 16%;
}
.ins-c-skeleton__sm {
  width: 33%;
}
.ins-c-skeleton__md {
  width: 66%;
}
.ins-c-skeleton__lg {
  width: 100%;
}
.ins-c-skeleton.ins-m-dark {
  background: #3c3c3c;
  background: linear-gradient(to right, #3c3c3c 10%, #484848 18%, #3c3c3c 33%);
  background-size: 1000px 50px;
  background-size: 62.5rem 3.125rem;
}

@keyframes skeletonGradient {
  0% {
    background-position: -500px 0px;
    background-position: -31.25rem 0rem;
  }
  100% {
    background-position: 500px 0px;
    background-position: 31.25rem 0rem;
  }
}
:root {
  --ins-color--orange: #ec7a08;
}

@keyframes spinner {
  to {
    transform: rotate(360deg);
  }
}
.ins-c-spinner {
  display: inline-flex;
}
.ins-c-spinner.ins-m-center {
  display: flex;
  justify-content: center;
}
.ins-c-spinner:before {
  content: "";
  width: 30px;
  width: 1.875rem;
  height: 30px;
  height: 1.875rem;
  border-radius: 50%;
  border: 3px solid var(--pf-global--active-color--200);
  border-top-color: var(--pf-global--active-color--100);
  animation: spinner 1s cubic-bezier(0.4, 0, 0.2, 1) infinite;
}

.ins-tab-layout > .ins-tabs div {
  display: inline-block;
  margin-right: 30px;
  text-align: center;
  cursor: pointer;
  color: var(--pf-global--link--Color);
}
.ins-tab-layout > .ins-tabs div.active {
  border-bottom: 3px var(--pf-global--link--Color) solid;
}
.ins-tab-layout > .ins-tabs div:hover {
  color: var(--pf-global--link--Color--hover);
  border-bottom: 3px var(--pf-global--link--Color--hover) solid;
}

:root {
  --ins-color--orange: #ec7a08;
}

:root {
  --ins-c-table-toolbar--PaddingVertical: 16px;
  --ins-c-table-toolbar--PaddingHorizontal: 32px;
}

.ins-c-table__toolbar, .ins-c-table__toolbar-results {
  background: var(--pf-global--Color--light-100);
  border-bottom: 1px solid var(--pf-global--BorderColor--light-200);
  padding: var(--ins-c-table-toolbar--PaddingVertical) var(--ins-c-table-toolbar--PaddingHorizontal);
}

.ins-c-table__toolbar.ins-m-footer {
  border-top: 1px solid var(--pf-global--BorderColor--light-200);
}

.ins-c-table__toolbar-results {
  color: var(--pf-global--Color--200);
}

.ins-c-table__toolbar-results-count + .ins-c-table__toolbar-results-selected {
  margin-left: 15px;
  margin-left: 0.9375rem;
  padding-left: 15px;
  padding-left: 0.9375rem;
  border-left: 2px solid var(--pf-global--BorderColor--light);
}

@media only screen and (max-width: 768px) {
  .ins-c-table__toolbar, .ins-c-table__toolbar-results {
    padding: 0 0;
  }
}
button.ins-c-tag-count {
  color: var(--pf-global--icon--Color--light);
  display: flex;
  align-content: center;
}

.ins-c-tag__text {
  margin-left: 10px;
}

.ins-c-tag-modal {
  height: calc(var(--pf-global--spacer--4xl) + var(--pf-global--breakpoint--md));
}

.pf-c-treeview {
  --pf-c-treeview--th--Padding: var(--pf-global--spacer--md);
  --pf-c-treeview--td--Padding: var(--pf-global--spacer--md);
  --pf-c-treeview--cell--Padding: var(--pf-global--spacer--md);
  --pf-c-treeview__toggle-button--Padding: var(--pf-c-treeview--td--Padding);
  --pf-c-treeview__control-toggle--Width: 42px;
  --pf-c-treeview__control-check--Width: 22px;
  --pf-c-treeview--td--level-2--PaddingLeft: calc(var(--pf-c-treeview--td--Padding) * 3);
  --pf-c-treeview--td--level-3--PaddingLeft: calc(var(--pf-c-treeview--td--Padding) * 5);
  --pf-c-treeview--level--PaddingLeft: var(--pf-global--spacer--xl);
  --pf-c-treeview__aria-level--GridColumn: 1;
  --pf-c-treeview--tr--Display: table-row;
  --pf-c-treeview--tr--Visibility: visible;
  width: 100%;
  border-collapse: collapse;
  --background: #fff;
  --background-base: #ddd;
}
.pf-c-treeview th,
.pf-c-treeview td {
  padding: var(--pf-c-treeview--cell--Padding);
  text-align: left;
  vertical-align: baseline;
}
.pf-c-treeview tr {
  border-bottom: 1px solid #ddd;
}
.pf-c-treeview tbody tr {
  display: none;
  visibility: hidden;
}
.pf-c-treeview [aria-level="1"] {
  display: table-row;
  visibility: visible;
  --pf-c-treeview--tr--Display: table-row;
  --pf-c-treeview--tr--Visibility: visible;
}
.pf-c-treeview .pf-m-hidden,
.pf-c-treeview tr.pf-m-hidden,
.pf-c-treeview td.pf-m-hidden,
.pf-c-treeview th.pf-m-hidden {
  display: none;
  visibility: hidden;
}
.pf-c-treeview tr.pf-m-visible {
  display: table-row;
  visibility: visible;
}
.pf-c-treeview td.pf-m-visible,
.pf-c-treeview th.pf-m-visible {
  display: table-cell;
  visibility: visible;
}
.pf-c-treeview .pf-c-treeview__check,
.pf-c-treeview .pf-c-treeview__action {
  width: 1px;
}
.pf-c-treeview th.pf-c-treeview__title-cell {
  padding-left: 0;
}
.pf-c-treeview tbody .pf-c-treeview__check + .pf-c-treeview__title-cell {
  padding-left: 0;
}
.pf-c-treeview .pf-c-treeview__toggle-icon {
  transition: 0.2s;
}
.pf-c-treeview .pf-c-treeview__action {
  text-align: right;
}
.pf-c-treeview tr {
  background: var(--background);
}

.pf-c-treeview tr[aria-level="1"] .pf-c-treeview__title-cell {
  padding-left: calc(var(--pf-c-treeview--level--PaddingLeft) * 0);
}
.pf-c-treeview tr[aria-level="2"] .pf-c-treeview__title-cell {
  padding-left: calc(var(--pf-c-treeview--level--PaddingLeft) * 1);
}
.pf-c-treeview tr[aria-level="3"] .pf-c-treeview__title-cell {
  padding-left: calc(var(--pf-c-treeview--level--PaddingLeft) * 2);
}
.pf-c-treeview tr[aria-level="4"] .pf-c-treeview__title-cell {
  padding-left: calc(var(--pf-c-treeview--level--PaddingLeft) * 3);
}
.pf-c-treeview tr[aria-level="5"] .pf-c-treeview__title-cell {
  padding-left: calc(var(--pf-c-treeview--level--PaddingLeft) * 4);
}
.pf-c-treeview tr[aria-level="6"] .pf-c-treeview__title-cell {
  padding-left: calc(var(--pf-c-treeview--level--PaddingLeft) * 5);
}
.pf-c-treeview tr[aria-level="7"] .pf-c-treeview__title-cell {
  padding-left: calc(var(--pf-c-treeview--level--PaddingLeft) * 6);
}
.pf-c-treeview tr[aria-level="8"] .pf-c-treeview__title-cell {
  padding-left: calc(var(--pf-c-treeview--level--PaddingLeft) * 7);
}
.pf-c-treeview tr[aria-level="9"] .pf-c-treeview__title-cell {
  padding-left: calc(var(--pf-c-treeview--level--PaddingLeft) * 8);
}
.pf-c-treeview tr[aria-level="10"] .pf-c-treeview__title-cell {
  padding-left: calc(var(--pf-c-treeview--level--PaddingLeft) * 9);
}
.pf-c-treeview tbody tr {
  display: none;
}
.pf-c-treeview [aria-level="1"] {
  display: table-row;
}
.pf-c-treeview [aria-level="1"].pf-m-expanded ~ [aria-level="2"] {
  display: table-row;
}
.pf-c-treeview [aria-level="2"].pf-m-expanded ~ [aria-level="3"] {
  display: table-row;
}
.pf-c-treeview [aria-level="3"].pf-m-expanded ~ [aria-level="4"] {
  display: table-row;
}
.pf-c-treeview [aria-level="4"].pf-m-expanded ~ [aria-level="5"] {
  display: table-row;
}
.pf-c-treeview [aria-level="5"].pf-m-expanded ~ [aria-level="6"] {
  display: table-row;
}
.pf-c-treeview [aria-level="6"].pf-m-expanded ~ [aria-level="7"] {
  display: table-row;
}
.pf-c-treeview [aria-level="7"].pf-m-expanded ~ [aria-level="8"] {
  display: table-row;
}
.pf-c-treeview [aria-level="8"].pf-m-expanded ~ [aria-level="9"] {
  display: table-row;
}
.pf-c-treeview [aria-level="9"].pf-m-expanded ~ [aria-level="10"] {
  display: table-row;
}
.pf-c-treeview [aria-level="10"].pf-m-expanded ~ [aria-level="11"] {
  display: table-row;
}
.pf-c-treeview tr.pf-m-expanded .pf-c-treeview__toggle-icon {
  transform: rotate(90deg);
}

.pf-c-treeview__control {
  display: grid;
  align-items: baseline;
}

.pf-c-treeview__control-toggle {
  grid-area: 1/toggle;
}

.pf-c-treeview__control-text {
  grid-area: 1/text;
  max-width: 100%;
  overflow: hidden;
  white-space: nowrap;
  text-overflow: ellipsis;
}

.pf-c-treeview__check {
  grid-row-start: 1;
  grid-column-start: 2;
}

.pf-c-treeview.pf-m-expandable .pf-c-treeview__control {
  grid-template-columns: [toggle] var(--pf-c-treeview__control-toggle--Width) [text] auto;
}

@media (max-width: 2000px) {
  .pf-c-treeview.pf-m-grid {
    width: 480px;
    background: lightgray;
    padding: 12px;
  }
  .pf-c-treeview.pf-m-grid,
.pf-c-treeview.pf-m-grid tr {
    display: grid;
  }
  .pf-c-treeview.pf-m-grid thead {
    display: none;
  }
  .pf-c-treeview.pf-m-grid tbody {
    display: grid;
  }
  .pf-c-treeview.pf-m-grid td,
.pf-c-treeview.pf-m-grid th {
    display: grid;
    grid-template-columns: 1fr 1.5fr;
    grid-column: 1;
    padding-left: 0;
    font-weight: normal;
  }
  .pf-c-treeview.pf-m-grid [data-label]::before {
    content: attr(data-label);
    grid-column: 1;
    font-weight: bold;
  }
  .pf-c-treeview.pf-m-grid [data-label] {
    grid-column-gap: var(--pf-global--spacer--md);
    padding-top: 8px;
    padding-bottom: 8px;
  }
  .pf-c-treeview.pf-m-grid [data-label] * {
    grid-column: 2;
  }
  .pf-c-treeview.pf-m-grid .pf-c-treeview__check,
.pf-c-treeview.pf-m-grid .pf-c-treeview__action {
    display: inline-block;
    width: auto;
    grid-row: 1;
    align-self: baseline;
    padding: 0;
  }
  .pf-c-treeview.pf-m-grid .pf-c-treeview__check {
    grid-column: 3;
  }
  .pf-c-treeview.pf-m-grid .pf-c-treeview__action {
    grid-column: 4;
  }
  .pf-c-treeview.pf-m-grid .pf-c-treeview__control {
    display: block;
  }
  .pf-c-treeview.pf-m-grid .pf-c-treeview__control .pf-c-treeview__toggle {
    display: none;
  }
  .pf-c-treeview.pf-m-grid [aria-level] .pf-c-treeview__title-cell {
    padding-left: 0;
  }
  .pf-c-treeview.pf-m-grid tr {
    grid-template-columns: 1fr;
    grid-auto-columns: max-content;
    padding: var(--pf-global--spacer--md);
    background: rgba(255, 255, 255, 0.5);
    display: none;
    visibility: hidden;
  }
}

.pf-c-treeview.pf-m-grid tr {
  display: none;
}
@media (max-width: 2000px) {
  .pf-c-treeview.pf-m-grid .pf-m-level-1 [aria-level="1"] {
    display: grid;
    visibility: visible;
  }
  .pf-c-treeview.pf-m-grid .pf-m-level-2 tr[aria-level="1"].pf-m-expanded ~ tr[aria-level="2"] {
    background: lightsalmon;
    display: grid;
    visibility: visible;
  }
  .pf-c-treeview.pf-m-grid .pf-m-level-2 tr[aria-level="1"].pf-m-expanded ~ tr[aria-level="1"] ~ tr[aria-level="2"] {
    display: none;
    visibility: hidden;
  }
  .pf-c-treeview.pf-m-grid .pf-m-level-3 tr[aria-level="2"].pf-m-expanded ~ tr[aria-level="3"] {
    background: lightsalmon;
    display: grid;
    visibility: visible;
  }
  .pf-c-treeview.pf-m-grid .pf-m-level-3 tr[aria-level="2"].pf-m-expanded ~ tr[aria-level="2"] ~ tr[aria-level="3"] {
    display: none;
    visibility: hidden;
  }
  .pf-c-treeview.pf-m-grid .pf-m-level-4 tr[aria-level="3"].pf-m-expanded ~ tr[aria-level="4"] {
    background: lightsalmon;
    display: grid;
    visibility: visible;
  }
  .pf-c-treeview.pf-m-grid .pf-m-level-4 tr[aria-level="3"].pf-m-expanded ~ tr[aria-level="3"] ~ tr[aria-level="4"] {
    display: none;
    visibility: hidden;
  }
  .pf-c-treeview.pf-m-grid .pf-m-level-5 tr[aria-level="4"].pf-m-expanded ~ tr[aria-level="5"] {
    background: lightsalmon;
    display: grid;
    visibility: visible;
  }
  .pf-c-treeview.pf-m-grid .pf-m-level-5 tr[aria-level="4"].pf-m-expanded ~ tr[aria-level="4"] ~ tr[aria-level="5"] {
    display: none;
    visibility: hidden;
  }
  .pf-c-treeview.pf-m-grid .pf-m-level-6 tr[aria-level="5"].pf-m-expanded ~ tr[aria-level="6"] {
    background: lightsalmon;
    display: grid;
    visibility: visible;
  }
  .pf-c-treeview.pf-m-grid .pf-m-level-6 tr[aria-level="5"].pf-m-expanded ~ tr[aria-level="5"] ~ tr[aria-level="6"] {
    display: none;
    visibility: hidden;
  }
  .pf-c-treeview.pf-m-grid .pf-m-level-7 tr[aria-level="6"].pf-m-expanded ~ tr[aria-level="7"] {
    background: lightsalmon;
    display: grid;
    visibility: visible;
  }
  .pf-c-treeview.pf-m-grid .pf-m-level-7 tr[aria-level="6"].pf-m-expanded ~ tr[aria-level="6"] ~ tr[aria-level="7"] {
    display: none;
    visibility: hidden;
  }
  .pf-c-treeview.pf-m-grid .pf-m-level-8 tr[aria-level="7"].pf-m-expanded ~ tr[aria-level="8"] {
    background: lightsalmon;
    display: grid;
    visibility: visible;
  }
  .pf-c-treeview.pf-m-grid .pf-m-level-8 tr[aria-level="7"].pf-m-expanded ~ tr[aria-level="7"] ~ tr[aria-level="8"] {
    display: none;
    visibility: hidden;
  }
  .pf-c-treeview.pf-m-grid .pf-m-level-9 tr[aria-level="8"].pf-m-expanded ~ tr[aria-level="9"] {
    background: lightsalmon;
    display: grid;
    visibility: visible;
  }
  .pf-c-treeview.pf-m-grid .pf-m-level-9 tr[aria-level="8"].pf-m-expanded ~ tr[aria-level="8"] ~ tr[aria-level="9"] {
    display: none;
    visibility: hidden;
  }
  .pf-c-treeview.pf-m-grid .pf-m-level-10 tr[aria-level="9"].pf-m-expanded ~ tr[aria-level="10"] {
    background: lightsalmon;
    display: grid;
    visibility: visible;
  }
  .pf-c-treeview.pf-m-grid .pf-m-level-10 tr[aria-level="9"].pf-m-expanded ~ tr[aria-level="9"] ~ tr[aria-level="10"] {
    display: none;
    visibility: hidden;
  }
  .pf-c-treeview.pf-m-grid .pf-m-level-11 tr[aria-level="10"].pf-m-expanded ~ tr[aria-level="11"] {
    background: lightsalmon;
    display: grid;
    visibility: visible;
  }
  .pf-c-treeview.pf-m-grid .pf-m-level-11 tr[aria-level="10"].pf-m-expanded ~ tr[aria-level="10"] ~ tr[aria-level="11"] {
    display: none;
    visibility: hidden;
  }
}

:root {
  --ins-color--orange: #ec7a08;
}

.ins-c-truncate button, .ins-c-truncate + button {
  padding: 0;
}

.ins-c-truncate.is-inline {
  margin-right: 10px;
  margin-right: 0.625rem;
}

.ins-c-empty-state__unavailable svg {
  color: var(--pf-global--danger-color--100);
}

.pf-c-modal-box.ins-c-wizard {
  min-height: 75vh;
  min-width: 75vw;
}
.pf-c-modal-box.ins-c-wizard .pf-c-modal-box__body {
  max-height: none;
}
:root{--ins-color--orange: #ec7a08}@keyframes spinner{to{transform:rotate(360deg)}}.ins-c-spinner{display:inline-flex}.ins-c-spinner.ins-m-center{display:flex;justify-content:center}.ins-c-spinner:before{content:"";width:30px;width:1.875rem;height:30px;height:1.875rem;border-radius:50%;border:3px solid var(--pf-global--active-color--200);border-top-color:var(--pf-global--active-color--100);animation:spinner 1s cubic-bezier(0.4, 0, 0.2, 1) infinite}
:root{--ins-color--orange: #ec7a08}.pf-l-page__main-section.pf-l-page-header.pf-m-dark-200 h1.pf-c-title.pf-m-2xl,.pf-l-page__main-section.pf-l-page-header.pf-m-dark-200 *{color:#fff}.pf-l-page__main-section.pf-l-page-header .pf-c-breadcrumb{display:block;margin-bottom:15px;margin-bottom:.9375rem}
:root{--ins-color--orange: #ec7a08}.ins-c-skeleton{animation-duration:1s;animation-iteration-count:infinite;animation-name:skeletonGradient;animation-timing-function:linear;background:var(--pf-global--disabled-color--200);background:linear-gradient(to right, #f5f5f5 10%, #e8e8e8 18%, #f5f5f5 33%);background-size:1000px 50px;background-size:62.5rem 3.125rem;border-radius:5px;border-radius:.3125rem}.ins-c-skeleton__xs{width:16%}.ins-c-skeleton__sm{width:33%}.ins-c-skeleton__md{width:66%}.ins-c-skeleton__lg{width:100%}.ins-c-skeleton.ins-m-dark{background:#3c3c3c;background:linear-gradient(to right, #3c3c3c 10%, #484848 18%, #3c3c3c 33%);background-size:1000px 50px;background-size:62.5rem 3.125rem}@keyframes skeletonGradient{0%{background-position:-500px 0px;background-position:-31.25rem 0rem}100%{background-position:500px 0px;background-position:31.25rem 0rem}}
:root{--ins-color--orange: #ec7a08}section.ins-l-content{padding:var(--pf-global--spacer--lg)}section.ins-l-button-group{margin:24px 0px;margin:1.5rem 0rem}section.ins-l-button-group>*{display:inline}section.ins-l-button-group *+*{margin-left:5px;margin-left:.3125rem}section.ins-l-icon-group *+*{margin-left:10px}section.ins-l-icon-group__with-major *+*{margin-left:7.5px}section.ins-l-icon-group__with-major .ins-battery:last-of-type{padding-left:15px;border-left:2px solid #eaeaea}section.ins-l-icon-group__with-major .ins-battery:last-of-type span.label{font-weight:500;margin:0 10px}

/*# sourceMappingURL=rhcsVendor.a266bd3b09a3288ea40c.css.map*/