# Generated by Django 2.2.15 on 2020-08-27 17:32

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('galaxy', '0006_collectionsynctask'),
        ('galaxy', '0006_merge_synclist_rbac'),
    ]

    operations = [
    ]
