# Generated by Django 2.2.19 on 2021-03-15 18:10

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('container', '0018_containerdistribution_description'),
        ('galaxy', '0014_containerdistribution'),
    ]

    operations = [
        migrations.CreateModel(
            name='ContainerDistroReadme',
            fields=[
                ('container', models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, primary_key=True, serialize=False, to='container.ContainerDistribution')),
                ('created', models.DateTimeField(auto_now_add=True)),
                ('updated', models.DateTimeField(auto_now=True, null=True)),
                ('text', models.TextField(blank=True)),
            ],
        ),
    ]
